/******************************************************************************
*
* Copyright (C) 2012 Ittiam Systems Pvt Ltd, Bangalore
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at:
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*
******************************************************************************/


/**
******************************************************************************
* @file
*  ihevc_cabac_tables.c
*
* @brief
*  This file contains HEVC cabac tables for init contexts, rlps and
*  cabac state trasnitions
*
* @author
*   Ittiam
*
* @par List of Tables
*   - gau1_ihevc_cabac_rlps[]
*   - gau1_ihevc_next_state[]
*   - gau1_ihevc_cab_ctxts[]
*
******************************************************************************
*/


/*****************************************************************************/
/* File Includes                                                             */
/*****************************************************************************/
#include "ihevc_typedefs.h"
#include "ihevc_cabac_tables.h"


/**
 ******************************************************************************
 * @brief  Table for rangeTabLPS depending on pStateIdx and qCodIRangeIdx
 * input   : pStateIdx(0-63) and qCodIRangeIdx(0-3) [(Range >> 6) & 0x3]
 * output  : RLps
 *
 * @remarks See Table 9-40 of HEVC spec for rangeTabLPS
 ******************************************************************************
 */
const UWORD8 gau1_ihevc_cabac_rlps[64][4] =
{
    { 128,  176,  208,  240 },
    { 128,  167,  197,  227 },
    { 128,  158,  187,  216 },
    { 123,  150,  178,  205 },
    { 116,  142,  169,  195 },
    { 111,  135,  160,  185 },
    { 105,  128,  152,  175 },
    { 100,  122,  144,  166 },
    {  95,  116,  137,  158 },
    {  90,  110,  130,  150 },
    {  85,  104,  123,  142 },
    {  81,   99,  117,  135 },
    {  77,   94,  111,  128 },
    {  73,   89,  105,  122 },
    {  69,   85,  100,  116 },
    {  66,   80,   95,  110 },
    {  62,   76,   90,  104 },
    {  59,   72,   86,   99 },
    {  56,   69,   81,   94 },
    {  53,   65,   77,   89 },
    {  51,   62,   73,   85 },
    {  48,   59,   69,   80 },
    {  46,   56,   66,   76 },
    {  43,   53,   63,   72 },
    {  41,   50,   59,   69 },
    {  39,   48,   56,   65 },
    {  37,   45,   54,   62 },
    {  35,   43,   51,   59 },
    {  33,   41,   48,   56 },
    {  32,   39,   46,   53 },
    {  30,   37,   43,   50 },
    {  29,   35,   41,   48 },
    {  27,   33,   39,   45 },
    {  26,   31,   37,   43 },
    {  24,   30,   35,   41 },
    {  23,   28,   33,   39 },
    {  22,   27,   32,   37 },
    {  21,   26,   30,   35 },
    {  20,   24,   29,   33 },
    {  19,   23,   27,   31 },
    {  18,   22,   26,   30 },
    {  17,   21,   25,   28 },
    {  16,   20,   23,   27 },
    {  15,   19,   22,   25 },
    {  14,   18,   21,   24 },
    {  14,   17,   20,   23 },
    {  13,   16,   19,   22 },
    {  12,   15,   18,   21 },
    {  12,   14,   17,   20 },
    {  11,   14,   16,   19 },
    {  11,   13,   15,   18 },
    {  10,   12,   15,   17 },
    {  10,   12,   14,   16 },
    {   9,   11,   13,   15 },
    {   9,   11,   12,   14 },
    {   8,   10,   12,   14 },
    {   8,    9,   11,   13 },
    {   7,    9,   11,   12 },
    {   7,    9,   10,   12 },
    {   7,    8,   10,   11 },
    {   6,    8,    9,   11 },
    {   6,    7,    9,   10 },
    {   6,    7,    8,    9 },
    {   2,    2,    2,    2 }
};


/**
 ******************************************************************************
 * @brief  probaility+MPS state transition tables based on cur State and bin
 * input  : curpState[bits7-2]  | curMPS[bit1] | decodedBin[bit0]
 * output : nextpState[bits6-1] | nextMPS[bit0]
 * @remarks Modified form of Table-9-41 State Transition table in HEVC spec
 ******************************************************************************
 */
const UWORD8 gau1_ihevc_next_state[64 * 2 * 2] =
{
/*****************************************************************************/
/*  m=0,b=0 | m=0,b=1 | m=1,b=0 | m=1,b=1                                    */
/*****************************************************************************/
      2,    1,    0,    3, /* mps reversal for m=0,b=1 / m=1,b=0 */
      4,    0,    1,    5,
      6,    2,    3,    7,
      8,    4,    5,    9,
     10,    4,    5,   11,
     12,    8,    9,   13,
     14,    8,    9,   15,
     16,   10,   11,   17,
     18,   12,   13,   19,
     20,   14,   15,   21,
     22,   16,   17,   23,
     24,   18,   19,   25,
     26,   18,   19,   27,
     28,   22,   23,   29,
     30,   22,   23,   31,
     32,   24,   25,   33,
     34,   26,   27,   35,
     36,   26,   27,   37,
     38,   30,   31,   39,
     40,   30,   31,   41,
     42,   32,   33,   43,
     44,   32,   33,   45,
     46,   36,   37,   47,
     48,   36,   37,   49,
     50,   38,   39,   51,
     52,   38,   39,   53,
     54,   42,   43,   55,
     56,   42,   43,   57,
     58,   44,   45,   59,
     60,   44,   45,   61,
     62,   46,   47,   63,
     64,   48,   49,   65,
     66,   48,   49,   67,
     68,   50,   51,   69,
     70,   52,   53,   71,
     72,   52,   53,   73,
     74,   54,   55,   75,
     76,   54,   55,   77,
     78,   56,   57,   79,
     80,   58,   59,   81,
     82,   58,   59,   83,
     84,   60,   61,   85,
     86,   60,   61,   87,
     88,   60,   61,   89,
     90,   62,   63,   91,
     92,   64,   65,   93,
     94,   64,   65,   95,
     96,   66,   67,   97,
     98,   66,   67,   99,
    100,   66,   67,  101,
    102,   68,   69,  103,
    104,   68,   69,  105,
    106,   70,   71,  107,
    108,   70,   71,  109,
    110,   70,   71,  111,
    112,   72,   73,  113,
    114,   72,   73,  115,
    116,   72,   73,  117,
    118,   74,   75,  119,
    120,   74,   75,  121,
    122,   74,   75,  123,
    124,   76,   77,  125,
    124,   76,   77,  125,
    126,  126,  127,  127
};


/*
******************************************************************************
* As per HEVC standard the Cabac values are generated using following logic
* (ref: section 9.3.1.1 of JCTVC-J1003_d7_DIS)
* From the 8 bit table entry initValue, the two 4 bit variables slopeIdx and
* intersecIdx are derived according to the following pseudo-code process
* slopeIdx = initValue >> 4
* intersecIdx = initValue & 15
*
* Slope m and Intersec n are derived from the indices as follows:
* m = slopeIdx*5 - 45
* n = ( intersecIdx << 3 ) - 16
*
* The two values assigned to pStateIdx and valMPS for the initialization
* are derived from SliceQPY, which is derived in Equation 7 35.
*
* Given the variable m and n, the initialization is specified by the following
* pseudo-code process
*
* preCtxState = Clip3( 1, 126, ( ( m * Clip3( 0, 51, SliceQPY ) ) >> 4 ) + n )
* valMPS = ( preCtxState  <=  63) ? 0 : 1
* pStateIdx = valMPS ? (preCtxState - 64) : (63 - preCtxState)
******************************************************************************
*/

/**
 ******************************************************************************
 * @brief  Init context tables for all combinations of qp and cabac_init_idc
 * @remarks Packing format MPS in lsb and pState in bits[1-6]
 ******************************************************************************
 */

const UWORD8 gau1_ihevc_cab_ctxts[IHEVC_NUM_CAB_IDC][IHEVC_MAX_QP][IHEVC_CAB_CTXT_END] =
{
    {
        {
            /* Context Tables for init_idc = 0, qp =  0 */

              14,   30,   17,   49,   49,    1,   81,   81,   81,    1,
               1,   81,   30,   81,   81,   81,   30,   81,   81,   81,
              81,   81,   81,   81,   81,   81,   81,   81,   81,   81,
              81,   14,    1,    1,   81,   49,   65,    1,   62,    1,
              17,   17,   65,   65,   33,   49,   33,   14,   49,   81,
              33,   49,   81,   81,   81,   81,   81,   33,   17,   81,
              65,   65,   33,   49,   33,   14,   49,   81,   33,   49,
              81,   81,   81,   81,   81,   33,   17,   81,   17,   17,
              62,   49,   81,   81,   49,   65,   65,   65,   33,   33,
              33,   17,   49,   49,  110,   14,   49,   17,   49,   49,
             110,   14,   49,   17,   49,   49,  110,   14,   49,   33,
              17,   62,   62,   30,   30,   30,   30,   14,   30,   17,
              81,   30,   17,   81,   33,   33,   14,    1,   33,   30,
               1,   17,   14,    1,   78,   33,   17,   17,    1,   30,
              33,  110,   62,   62,   33,  110,    1,   78,    1,   14,
              30,   46,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp =  1 */

              14,   30,   15,   47,   49,    1,   83,   83,   83,    1,
               1,   83,   30,   83,   83,   83,   30,   77,   83,   83,
              83,   83,   83,   83,   83,   83,   83,   83,   83,   83,
              83,   14,    0,    0,   79,   47,   61,    0,   62,    1,
              15,   15,   63,   63,   31,   47,   31,   14,   47,   79,
              31,   47,   79,   79,   79,   79,   77,   31,   15,   77,
              63,   63,   31,   47,   31,   14,   47,   79,   31,   47,
              79,   79,   79,   79,   77,   31,   15,   77,   13,   17,
              64,   47,   79,   79,   47,   63,   63,   61,   31,   31,
              31,   15,   47,   47,  110,   14,   47,   15,   47,   47,
             110,   14,   47,   15,   47,   47,  110,   14,   47,   31,
              15,   62,   62,   30,   32,   30,   32,   14,   32,   15,
              79,   32,   15,   79,   31,   29,   16,    0,   31,   30,
               0,   15,   14,    2,   78,   29,   15,   15,    0,   30,
              31,  110,   62,   62,   31,  108,    0,   78,    0,   14,
              32,   46,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp =  2 */

              14,   28,   15,   47,   49,    1,   87,   87,   87,    1,
               1,   87,   28,   87,   87,   87,   28,   73,   87,   87,
              87,   87,   87,   87,   87,   87,   87,   87,   87,   87,
              87,   14,    0,    0,   77,   47,   59,    0,   60,    1,
              15,   15,   61,   61,   29,   45,   31,   14,   45,   77,
              31,   45,   77,   79,   77,   77,   73,   29,   13,   73,
              61,   61,   29,   45,   31,   14,   45,   77,   31,   45,
              77,   79,   77,   77,   73,   29,   13,   73,   11,   17,
              64,   47,   77,   77,   45,   61,   61,   59,   29,   29,
              29,   13,   45,   47,  108,   14,   45,   13,   45,   47,
             108,   14,   45,   13,   45,   47,  108,   14,   45,   31,
              15,   60,   60,   30,   32,   30,   32,   14,   32,   15,
              77,   32,   15,   77,   31,   27,   16,    0,   31,   30,
               0,   15,   14,    6,   78,   27,   15,   13,    2,   30,
              31,  108,   62,   60,   31,  104,    2,   76,    0,   14,
              32,   46,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp =  3 */

              14,   26,   15,   47,   49,    1,   91,   91,   91,    1,
               1,   91,   28,   91,   91,   91,   28,   69,   91,   91,
              91,   91,   91,   91,   91,   91,   91,   91,   91,   91,
              91,   14,    0,    0,   75,   47,   57,    0,   60,    1,
              15,   15,   59,   59,   29,   45,   31,   14,   45,   77,
              31,   43,   75,   79,   77,   75,   71,   27,   13,   69,
              59,   59,   29,   45,   31,   14,   45,   77,   31,   43,
              75,   79,   77,   75,   71,   27,   13,   69,    9,   17,
              64,   47,   75,   75,   45,   59,   59,   57,   29,   27,
              29,   11,   45,   47,  108,   14,   45,   11,   45,   47,
             108,   14,   45,   11,   45,   47,  108,   14,   45,   31,
              15,   60,   60,   30,   32,   30,   32,   14,   32,   15,
              75,   32,   15,   75,   31,   25,   16,    0,   31,   30,
               0,   15,   14,    8,   78,   25,   15,   11,    2,   30,
              31,  108,   62,   60,   31,  102,    2,   74,    0,   14,
              32,   46,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp =  4 */

              14,   24,   13,   45,   49,    1,   95,   95,   95,    1,
               1,   95,   26,   95,   95,   95,   26,   65,   95,   95,
              95,   95,   95,   95,   95,   95,   95,   95,   95,   95,
              95,   14,    2,    2,   73,   45,   55,    2,   58,    1,
              13,   13,   57,   57,   27,   43,   29,   14,   43,   75,
              29,   41,   73,   77,   75,   73,   67,   25,   11,   65,
              57,   57,   27,   43,   29,   14,   43,   75,   29,   41,
              73,   77,   75,   73,   67,   25,   11,   65,    7,   19,
              66,   45,   73,   73,   43,   57,   57,   55,   27,   25,
              27,    9,   43,   45,  106,   14,   43,    9,   43,   45,
             106,   14,   43,    9,   43,   45,  106,   14,   43,   29,
              13,   58,   58,   30,   34,   30,   34,   14,   34,   13,
              73,   34,   13,   73,   29,   23,   18,    2,   29,   30,
               2,   13,   14,   12,   78,   23,   13,    9,    4,   30,
              29,  106,   60,   58,   29,   98,    4,   72,    2,   14,
              34,   44,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp =  5 */

              14,   22,   13,   45,   49,    1,   99,   99,   99,    1,
               1,   99,   24,   99,   99,   99,   24,   61,   99,   99,
              99,   99,   99,   99,   99,   99,   99,   99,   99,   99,
              99,   14,    2,    2,   71,   45,   51,    2,   56,    1,
              13,   13,   55,   55,   25,   41,   29,   14,   41,   73,
              29,   39,   71,   77,   73,   71,   65,   23,    9,   61,
              55,   55,   25,   41,   29,   14,   41,   73,   29,   39,
              71,   77,   73,   71,   65,   23,    9,   61,    3,   19,
              66,   45,   71,   71,   41,   55,   55,   51,   25,   23,
              25,    7,   41,   45,  104,   14,   41,    7,   41,   45,
             104,   14,   41,    7,   41,   45,  104,   14,   41,   29,
              13,   56,   56,   30,   34,   30,   34,   14,   34,   13,
              71,   34,   13,   71,   29,   19,   18,    2,   29,   30,
               2,   13,   14,   14,   78,   19,   13,    7,    6,   30,
              29,  104,   60,   56,   29,   96,    6,   70,    2,   14,
              34,   44,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp =  6 */

              14,   20,   13,   45,   49,    1,  103,  103,  103,    1,
               1,  103,   24,  103,  103,  103,   24,   57,  103,  103,
             103,  103,  103,  103,  103,  103,  103,  103,  103,  103,
             103,   14,    2,    2,   69,   45,   49,    2,   56,    1,
              13,   13,   53,   53,   25,   41,   29,   14,   41,   73,
              29,   37,   69,   77,   73,   69,   61,   21,    9,   57,
              53,   53,   25,   41,   29,   14,   41,   73,   29,   37,
              69,   77,   73,   69,   61,   21,    9,   57,    1,   19,
              66,   45,   69,   69,   41,   53,   53,   49,   25,   21,
              25,    5,   41,   45,  104,   14,   41,    5,   41,   45,
             104,   14,   41,    5,   41,   45,  104,   14,   41,   29,
              13,   56,   56,   30,   34,   30,   34,   14,   34,   13,
              69,   34,   13,   69,   29,   17,   18,    2,   29,   30,
               2,   13,   14,   18,   78,   17,   13,    5,    6,   30,
              29,  104,   60,   56,   29,   92,    6,   68,    2,   14,
              34,   44,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp =  7 */

              14,   18,   11,   43,   49,    1,  107,  107,  107,    1,
               1,  107,   22,  107,  107,  107,   22,   53,  107,  107,
             107,  107,  107,  107,  107,  107,  107,  107,  107,  107,
             107,   14,    4,    4,   67,   43,   47,    4,   54,    1,
              11,   11,   51,   51,   23,   39,   27,   14,   39,   71,
              27,   35,   67,   75,   71,   67,   59,   19,    7,   53,
              51,   51,   23,   39,   27,   14,   39,   71,   27,   35,
              67,   75,   71,   67,   59,   19,    7,   53,    0,   21,
              68,   43,   67,   67,   39,   51,   51,   47,   23,   19,
              23,    3,   39,   43,  102,   14,   39,    3,   39,   43,
             102,   14,   39,    3,   39,   43,  102,   14,   39,   27,
              11,   54,   54,   30,   36,   30,   36,   14,   36,   11,
              67,   36,   11,   67,   27,   15,   20,    4,   27,   30,
               4,   11,   14,   20,   78,   15,   11,    3,    8,   30,
              27,  102,   58,   54,   27,   90,    8,   66,    4,   14,
              36,   42,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp =  8 */

              14,   16,   11,   43,   49,    1,  111,  111,  111,    1,
               1,  111,   20,  111,  111,  111,   20,   51,  111,  111,
             111,  111,  111,  111,  111,  111,  111,  111,  111,  111,
             111,   14,    4,    4,   65,   43,   45,    4,   52,    1,
              11,   11,   49,   49,   23,   39,   27,   14,   39,   71,
              27,   33,   65,   75,   71,   65,   55,   17,    7,   51,
              49,   49,   23,   39,   27,   14,   39,   71,   27,   33,
              65,   75,   71,   65,   55,   17,    7,   51,    2,   21,
              68,   43,   65,   65,   39,   49,   49,   45,   23,   17,
              23,    1,   39,   43,  100,   14,   39,    1,   39,   43,
             100,   14,   39,    1,   39,   43,  100,   14,   39,   27,
              11,   52,   52,   30,   36,   30,   36,   14,   36,   11,
              65,   36,   11,   65,   27,   13,   20,    4,   27,   30,
               4,   11,   14,   24,   78,   13,   11,    1,    8,   30,
              27,  100,   58,   52,   27,   86,    8,   64,    4,   14,
              36,   42,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp =  9 */

              14,   14,   11,   43,   49,    1,  113,  113,  113,    1,
               1,  113,   20,  113,  113,  113,   20,   47,  113,  113,
             113,  113,  113,  113,  113,  113,  113,  113,  113,  113,
             113,   14,    4,    4,   63,   43,   41,    4,   52,    1,
              11,   11,   47,   47,   21,   37,   27,   14,   37,   69,
              27,   31,   63,   75,   69,   63,   51,   15,    5,   47,
              47,   47,   21,   37,   27,   14,   37,   69,   27,   31,
              63,   75,   69,   63,   51,   15,    5,   47,    6,   21,
              68,   43,   63,   63,   37,   47,   47,   41,   21,   15,
              21,    0,   37,   43,  100,   14,   37,    0,   37,   43,
             100,   14,   37,    0,   37,   43,  100,   14,   37,   27,
              11,   52,   52,   30,   36,   30,   36,   14,   36,   11,
              63,   36,   11,   63,   27,    9,   20,    4,   27,   30,
               4,   11,   14,   28,   78,    9,   11,    0,   10,   30,
              27,  100,   58,   52,   27,   82,   10,   62,    4,   14,
              36,   42,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp = 10 */

              14,   12,    9,   41,   49,    1,  117,  117,  117,    1,
               1,  117,   18,  117,  117,  117,   18,   43,  117,  117,
             117,  117,  117,  117,  117,  117,  117,  117,  117,  117,
             117,   14,    6,    6,   61,   41,   39,    6,   50,    1,
               9,    9,   45,   45,   19,   35,   25,   14,   35,   67,
              25,   29,   61,   73,   67,   61,   49,   13,    3,   43,
              45,   45,   19,   35,   25,   14,   35,   67,   25,   29,
              61,   73,   67,   61,   49,   13,    3,   43,    8,   23,
              70,   41,   61,   61,   35,   45,   45,   39,   19,   13,
              19,    2,   35,   41,   98,   14,   35,    2,   35,   41,
              98,   14,   35,    2,   35,   41,   98,   14,   35,   25,
               9,   50,   50,   30,   38,   30,   38,   14,   38,    9,
              61,   38,    9,   61,   25,    7,   22,    6,   25,   30,
               6,    9,   14,   30,   78,    7,    9,    2,   12,   30,
              25,   98,   56,   50,   25,   80,   12,   60,    6,   14,
              38,   40,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp = 11 */

              14,   10,    9,   41,   49,    1,  121,  121,  121,    1,
               1,  121,   18,  121,  121,  121,   18,   39,  121,  121,
             121,  121,  121,  121,  121,  121,  121,  121,  121,  121,
             121,   14,    6,    6,   59,   41,   37,    6,   50,    1,
               9,    9,   43,   43,   19,   35,   25,   14,   35,   67,
              25,   27,   59,   73,   67,   59,   45,   11,    3,   39,
              43,   43,   19,   35,   25,   14,   35,   67,   25,   27,
              59,   73,   67,   59,   45,   11,    3,   39,   10,   23,
              70,   41,   59,   59,   35,   43,   43,   37,   19,   11,
              19,    4,   35,   41,   98,   14,   35,    4,   35,   41,
              98,   14,   35,    4,   35,   41,   98,   14,   35,   25,
               9,   50,   50,   30,   38,   30,   38,   14,   38,    9,
              59,   38,    9,   59,   25,    5,   22,    6,   25,   30,
               6,    9,   14,   34,   78,    5,    9,    4,   12,   30,
              25,   98,   56,   50,   25,   76,   12,   58,    6,   14,
              38,   40,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp = 12 */

              14,    8,    9,   41,   49,    1,  125,  125,  125,    1,
               1,  125,   16,  125,  125,  125,   16,   35,  125,  125,
             125,  125,  125,  125,  125,  125,  125,  125,  125,  125,
             125,   14,    6,    6,   57,   41,   35,    6,   48,    1,
               9,    9,   41,   41,   17,   33,   25,   14,   33,   65,
              25,   25,   57,   73,   65,   57,   43,    9,    1,   35,
              41,   41,   17,   33,   25,   14,   33,   65,   25,   25,
              57,   73,   65,   57,   43,    9,    1,   35,   12,   23,
              70,   41,   57,   57,   33,   41,   41,   35,   17,    9,
              17,    6,   33,   41,   96,   14,   33,    6,   33,   41,
              96,   14,   33,    6,   33,   41,   96,   14,   33,   25,
               9,   48,   48,   30,   38,   30,   38,   14,   38,    9,
              57,   38,    9,   57,   25,    3,   22,    6,   25,   30,
               6,    9,   14,   36,   78,    3,    9,    6,   14,   30,
              25,   96,   56,   48,   25,   74,   14,   56,    6,   14,
              38,   40,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp = 13 */

              14,    6,    7,   39,   49,    1,  125,  125,  125,    1,
               1,  125,   14,  125,  125,  125,   14,   31,  125,  125,
             125,  125,  125,  125,  125,  125,  125,  125,  125,  125,
             125,   14,    8,    8,   55,   39,   31,    8,   46,    1,
               7,    7,   39,   39,   15,   31,   23,   14,   31,   63,
              23,   23,   55,   71,   63,   55,   39,    7,    0,   31,
              39,   39,   15,   31,   23,   14,   31,   63,   23,   23,
              55,   71,   63,   55,   39,    7,    0,   31,   16,   25,
              72,   39,   55,   55,   31,   39,   39,   31,   15,    7,
              15,    8,   31,   39,   94,   14,   31,    8,   31,   39,
              94,   14,   31,    8,   31,   39,   94,   14,   31,   23,
               7,   46,   46,   30,   40,   30,   40,   14,   40,    7,
              55,   40,    7,   55,   23,    0,   24,    8,   23,   30,
               8,    7,   14,   40,   78,    0,    7,    8,   16,   30,
              23,   94,   54,   46,   23,   70,   16,   54,    8,   14,
              40,   38,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp = 14 */

              14,    4,    7,   39,   49,    1,  125,  125,  125,    1,
               1,  125,   14,  125,  125,  125,   14,   27,  125,  125,
             125,  125,  125,  125,  125,  125,  125,  125,  125,  125,
             125,   14,    8,    8,   53,   39,   29,    8,   46,    1,
               7,    7,   37,   37,   15,   31,   23,   14,   31,   63,
              23,   21,   53,   71,   63,   53,   37,    5,    0,   27,
              37,   37,   15,   31,   23,   14,   31,   63,   23,   21,
              53,   71,   63,   53,   37,    5,    0,   27,   18,   25,
              72,   39,   53,   53,   31,   37,   37,   29,   15,    5,
              15,   10,   31,   39,   94,   14,   31,   10,   31,   39,
              94,   14,   31,   10,   31,   39,   94,   14,   31,   23,
               7,   46,   46,   30,   40,   30,   40,   14,   40,    7,
              53,   40,    7,   53,   23,    2,   24,    8,   23,   30,
               8,    7,   14,   42,   78,    2,    7,   10,   16,   30,
              23,   94,   54,   46,   23,   68,   16,   52,    8,   14,
              40,   38,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp = 15 */

              14,    2,    7,   39,   49,    1,  125,  125,  125,    1,
               1,  125,   12,  125,  125,  125,   12,   23,  125,  125,
             125,  125,  125,  125,  125,  125,  125,  125,  125,  125,
             125,   14,    8,    8,   51,   39,   27,    8,   44,    1,
               7,    7,   35,   35,   13,   29,   23,   14,   29,   61,
              23,   19,   51,   71,   61,   51,   33,    3,    2,   23,
              35,   35,   13,   29,   23,   14,   29,   61,   23,   19,
              51,   71,   61,   51,   33,    3,    2,   23,   20,   25,
              72,   39,   51,   51,   29,   35,   35,   27,   13,    3,
              13,   12,   29,   39,   92,   14,   29,   12,   29,   39,
              92,   14,   29,   12,   29,   39,   92,   14,   29,   23,
               7,   44,   44,   30,   40,   30,   40,   14,   40,    7,
              51,   40,    7,   51,   23,    4,   24,    8,   23,   30,
               8,    7,   14,   46,   78,    4,    7,   12,   18,   30,
              23,   92,   54,   44,   23,   64,   18,   50,    8,   14,
              40,   38,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp = 16 */

              14,    0,    7,   39,   49,    1,  125,  125,  125,    1,
               1,  125,   10,  125,  125,  125,   10,   21,  125,  125,
             125,  125,  125,  125,  125,  125,  125,  125,  125,  125,
             125,   14,    8,    8,   51,   39,   25,    8,   42,    1,
               7,    7,   35,   35,   13,   29,   23,   14,   29,   61,
              23,   19,   51,   71,   61,   51,   31,    3,    2,   21,
              35,   35,   13,   29,   23,   14,   29,   61,   23,   19,
              51,   71,   61,   51,   31,    3,    2,   21,   22,   27,
              72,   39,   51,   51,   29,   35,   35,   25,   13,    3,
              13,   12,   29,   39,   90,   14,   29,   12,   29,   39,
              90,   14,   29,   12,   29,   39,   90,   14,   29,   23,
               7,   42,   42,   30,   40,   30,   40,   14,   40,    7,
              51,   40,    7,   51,   23,    6,   24,    8,   23,   30,
               8,    7,   14,   48,   78,    6,    7,   12,   18,   30,
              23,   90,   52,   42,   23,   60,   18,   48,    8,   14,
              40,   36,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp = 17 */

              14,    0,    5,   37,   49,    1,  125,  125,  125,    1,
               1,  125,   10,  125,  125,  125,   10,   17,  125,  125,
             125,  125,  125,  125,  125,  125,  125,  125,  125,  125,
             125,   14,   10,   10,   49,   37,   21,   10,   42,    1,
               5,    5,   33,   33,   11,   27,   21,   14,   27,   59,
              21,   17,   49,   69,   59,   49,   27,    1,    4,   17,
              33,   33,   11,   27,   21,   14,   27,   59,   21,   17,
              49,   69,   59,   49,   27,    1,    4,   17,   26,   27,
              74,   37,   49,   49,   27,   33,   33,   21,   11,    1,
              11,   14,   27,   37,   90,   14,   27,   14,   27,   37,
              90,   14,   27,   14,   27,   37,   90,   14,   27,   21,
               5,   42,   42,   30,   42,   30,   42,   14,   42,    5,
              49,   42,    5,   49,   21,   10,   26,   10,   21,   30,
              10,    5,   14,   52,   78,   10,    5,   14,   20,   30,
              21,   90,   52,   42,   21,   58,   20,   48,   10,   14,
              42,   36,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp = 18 */

              14,    1,    5,   37,   49,    1,  125,  125,  125,    1,
               1,  125,    8,  125,  125,  125,    8,   13,  125,  125,
             125,  125,  125,  125,  125,  125,  125,  125,  125,  125,
             125,   14,   10,   10,   47,   37,   19,   10,   40,    1,
               5,    5,   31,   31,    9,   25,   21,   14,   25,   57,
              21,   15,   47,   69,   57,   47,   23,    0,    6,   13,
              31,   31,    9,   25,   21,   14,   25,   57,   21,   15,
              47,   69,   57,   47,   23,    0,    6,   13,   28,   27,
              74,   37,   47,   47,   25,   31,   31,   19,    9,    0,
               9,   16,   25,   37,   88,   14,   25,   16,   25,   37,
              88,   14,   25,   16,   25,   37,   88,   14,   25,   21,
               5,   40,   40,   30,   42,   30,   42,   14,   42,    5,
              47,   42,    5,   47,   21,   12,   26,   10,   21,   30,
              10,    5,   14,   56,   78,   12,    5,   16,   22,   30,
              21,   88,   52,   40,   21,   54,   22,   46,   10,   14,
              42,   36,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp = 19 */

              14,    3,    5,   37,   49,    1,  125,  125,  125,    1,
               1,  125,    8,  125,  125,  125,    8,    9,  125,  125,
             125,  125,  125,  125,  125,  125,  125,  125,  125,  125,
             125,   14,   10,   10,   45,   37,   17,   10,   40,    1,
               5,    5,   29,   29,    9,   25,   21,   14,   25,   57,
              21,   13,   45,   69,   57,   45,   21,    2,    6,    9,
              29,   29,    9,   25,   21,   14,   25,   57,   21,   13,
              45,   69,   57,   45,   21,    2,    6,    9,   30,   27,
              74,   37,   45,   45,   25,   29,   29,   17,    9,    2,
               9,   18,   25,   37,   88,   14,   25,   18,   25,   37,
              88,   14,   25,   18,   25,   37,   88,   14,   25,   21,
               5,   40,   40,   30,   42,   30,   42,   14,   42,    5,
              45,   42,    5,   45,   21,   14,   26,   10,   21,   30,
              10,    5,   14,   58,   78,   14,    5,   18,   22,   30,
              21,   88,   52,   40,   21,   52,   22,   44,   10,   14,
              42,   36,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp = 20 */

              14,    5,    3,   35,   49,    1,  125,  125,  125,    1,
               1,  125,    6,  125,  125,  125,    6,    5,  125,  125,
             125,  125,  125,  125,  125,  125,  125,  125,  125,  125,
             125,   14,   12,   12,   43,   35,   15,   12,   38,    1,
               3,    3,   27,   27,    7,   23,   19,   14,   23,   55,
              19,   11,   43,   67,   55,   43,   17,    4,    8,    5,
              27,   27,    7,   23,   19,   14,   23,   55,   19,   11,
              43,   67,   55,   43,   17,    4,    8,    5,   32,   29,
              76,   35,   43,   43,   23,   27,   27,   15,    7,    4,
               7,   20,   23,   35,   86,   14,   23,   20,   23,   35,
              86,   14,   23,   20,   23,   35,   86,   14,   23,   19,
               3,   38,   38,   30,   44,   30,   44,   14,   44,    3,
              43,   44,    3,   43,   19,   16,   28,   12,   19,   30,
              12,    3,   14,   62,   78,   16,    3,   20,   24,   30,
              19,   86,   50,   38,   19,   48,   24,   42,   12,   14,
              44,   34,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp = 21 */

              14,    7,    3,   35,   49,    1,  125,  125,  125,    1,
               1,  125,    4,  125,  125,  125,    4,    1,  125,  125,
             125,  125,  125,  125,  125,  125,  125,  125,  125,  125,
             125,   14,   12,   12,   41,   35,   11,   12,   36,    1,
               3,    3,   25,   25,    5,   21,   19,   14,   21,   53,
              19,    9,   41,   67,   53,   41,   15,    6,   10,    1,
              25,   25,    5,   21,   19,   14,   21,   53,   19,    9,
              41,   67,   53,   41,   15,    6,   10,    1,   36,   29,
              76,   35,   41,   41,   21,   25,   25,   11,    5,    6,
               5,   22,   21,   35,   84,   14,   21,   22,   21,   35,
              84,   14,   21,   22,   21,   35,   84,   14,   21,   19,
               3,   36,   36,   30,   44,   30,   44,   14,   44,    3,
              41,   44,    3,   41,   19,   20,   28,   12,   19,   30,
              12,    3,   14,   64,   78,   20,    3,   22,   26,   30,
              19,   84,   50,   36,   19,   46,   26,   40,   12,   14,
              44,   34,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp = 22 */

              14,    9,    3,   35,   49,    1,  125,  125,  125,    1,
               1,  125,    4,  125,  125,  125,    4,    2,  125,  125,
             125,  125,  125,  125,  125,  125,  125,  125,  125,  125,
             125,   14,   12,   12,   39,   35,    9,   12,   36,    1,
               3,    3,   23,   23,    5,   21,   19,   14,   21,   53,
              19,    7,   39,   67,   53,   39,   11,    8,   10,    2,
              23,   23,    5,   21,   19,   14,   21,   53,   19,    7,
              39,   67,   53,   39,   11,    8,   10,    2,   38,   29,
              76,   35,   39,   39,   21,   23,   23,    9,    5,    8,
               5,   24,   21,   35,   84,   14,   21,   24,   21,   35,
              84,   14,   21,   24,   21,   35,   84,   14,   21,   19,
               3,   36,   36,   30,   44,   30,   44,   14,   44,    3,
              39,   44,    3,   39,   19,   22,   28,   12,   19,   30,
              12,    3,   14,   68,   78,   22,    3,   24,   26,   30,
              19,   84,   50,   36,   19,   42,   26,   38,   12,   14,
              44,   34,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp = 23 */

              14,   11,    1,   33,   49,    1,  125,  125,  125,    1,
               1,  125,    2,  125,  125,  125,    2,    6,  125,  125,
             125,  125,  125,  125,  125,  125,  125,  125,  125,  125,
             125,   14,   14,   14,   37,   33,    7,   14,   34,    1,
               1,    1,   21,   21,    3,   19,   17,   14,   19,   51,
              17,    5,   37,   65,   51,   37,    9,   10,   12,    6,
              21,   21,    3,   19,   17,   14,   19,   51,   17,    5,
              37,   65,   51,   37,    9,   10,   12,    6,   40,   31,
              78,   33,   37,   37,   19,   21,   21,    7,    3,   10,
               3,   26,   19,   33,   82,   14,   19,   26,   19,   33,
              82,   14,   19,   26,   19,   33,   82,   14,   19,   17,
               1,   34,   34,   30,   46,   30,   46,   14,   46,    1,
              37,   46,    1,   37,   17,   24,   30,   14,   17,   30,
              14,    1,   14,   70,   78,   24,    1,   26,   28,   30,
              17,   82,   48,   34,   17,   40,   28,   36,   14,   14,
              46,   32,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp = 24 */

              14,   13,    1,   33,   49,    1,  125,  125,  125,    1,
               1,  125,    0,  125,  125,  125,    0,    8,  125,  125,
             125,  125,  125,  125,  125,  125,  125,  125,  125,  125,
             125,   14,   14,   14,   35,   33,    5,   14,   32,    1,
               1,    1,   19,   19,    3,   19,   17,   14,   19,   51,
              17,    3,   35,   65,   51,   35,    5,   12,   12,    8,
              19,   19,    3,   19,   17,   14,   19,   51,   17,    3,
              35,   65,   51,   35,    5,   12,   12,    8,   42,   31,
              78,   33,   35,   35,   19,   19,   19,    5,    3,   12,
               3,   28,   19,   33,   80,   14,   19,   28,   19,   33,
              80,   14,   19,   28,   19,   33,   80,   14,   19,   17,
               1,   32,   32,   30,   46,   30,   46,   14,   46,    1,
              35,   46,    1,   35,   17,   26,   30,   14,   17,   30,
              14,    1,   14,   74,   78,   26,    1,   28,   28,   30,
              17,   80,   48,   32,   17,   36,   28,   34,   14,   14,
              46,   32,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp = 25 */

              14,   15,    1,   33,   49,    1,  125,  125,  125,    1,
               1,  125,    0,  125,  125,  125,    0,   12,  125,  125,
             125,  125,  125,  125,  125,  125,  125,  125,  125,  125,
             125,   14,   14,   14,   33,   33,    1,   14,   32,    1,
               1,    1,   17,   17,    1,   17,   17,   14,   17,   49,
              17,    1,   33,   65,   49,   33,    1,   14,   14,   12,
              17,   17,    1,   17,   17,   14,   17,   49,   17,    1,
              33,   65,   49,   33,    1,   14,   14,   12,   46,   31,
              78,   33,   33,   33,   17,   17,   17,    1,    1,   14,
               1,   30,   17,   33,   80,   14,   17,   30,   17,   33,
              80,   14,   17,   30,   17,   33,   80,   14,   17,   17,
               1,   32,   32,   30,   46,   30,   46,   14,   46,    1,
              33,   46,    1,   33,   17,   30,   30,   14,   17,   30,
              14,    1,   14,   78,   78,   30,    1,   30,   30,   30,
              17,   80,   48,   32,   17,   32,   30,   32,   14,   14,
              46,   32,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp = 26 */

              14,   17,    0,   31,   49,    1,  125,  125,  125,    1,
               1,  125,    1,  125,  125,  125,    1,   16,  125,  125,
             125,  125,  125,  125,  125,  125,  125,  125,  125,  125,
             125,   14,   16,   16,   31,   31,    0,   16,   30,    1,
               0,    0,   15,   15,    0,   15,   15,   14,   15,   47,
              15,    0,   31,   63,   47,   31,    0,   16,   16,   16,
              15,   15,    0,   15,   15,   14,   15,   47,   15,    0,
              31,   63,   47,   31,    0,   16,   16,   16,   48,   33,
              80,   31,   31,   31,   15,   15,   15,    0,    0,   16,
               0,   32,   15,   31,   78,   14,   15,   32,   15,   31,
              78,   14,   15,   32,   15,   31,   78,   14,   15,   15,
               0,   30,   30,   30,   48,   30,   48,   14,   48,    0,
              31,   48,    0,   31,   15,   32,   32,   16,   15,   30,
              16,    0,   14,   80,   78,   32,    0,   32,   32,   30,
              15,   78,   46,   30,   15,   30,   32,   30,   16,   14,
              48,   30,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp = 27 */

              14,   19,    0,   31,   49,    1,  125,  125,  125,    1,
               1,  125,    1,  125,  125,  125,    1,   20,  125,  125,
             125,  125,  125,  125,  125,  125,  125,  125,  125,  125,
             125,   14,   16,   16,   29,   31,    2,   16,   30,    1,
               0,    0,   13,   13,    0,   15,   15,   14,   15,   47,
              15,    2,   29,   63,   47,   29,    4,   18,   16,   20,
              13,   13,    0,   15,   15,   14,   15,   47,   15,    2,
              29,   63,   47,   29,    4,   18,   16,   20,   50,   33,
              80,   31,   29,   29,   15,   13,   13,    2,    0,   18,
               0,   34,   15,   31,   78,   14,   15,   34,   15,   31,
              78,   14,   15,   34,   15,   31,   78,   14,   15,   15,
               0,   30,   30,   30,   48,   30,   48,   14,   48,    0,
              29,   48,    0,   29,   15,   34,   32,   16,   15,   30,
              16,    0,   14,   84,   78,   34,    0,   34,   32,   30,
              15,   78,   46,   30,   15,   26,   32,   28,   16,   14,
              48,   30,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp = 28 */

              14,   21,    0,   31,   49,    1,  125,  125,  125,    1,
               1,  125,    3,  125,  125,  125,    3,   24,  125,  125,
             125,  125,  125,  125,  125,  125,  125,  125,  125,  125,
             125,   14,   16,   16,   27,   31,    4,   16,   28,    1,
               0,    0,   11,   11,    2,   13,   15,   14,   13,   45,
              15,    4,   27,   63,   45,   27,    6,   20,   18,   24,
              11,   11,    2,   13,   15,   14,   13,   45,   15,    4,
              27,   63,   45,   27,    6,   20,   18,   24,   52,   33,
              80,   31,   27,   27,   13,   11,   11,    4,    2,   20,
               2,   36,   13,   31,   76,   14,   13,   36,   13,   31,
              76,   14,   13,   36,   13,   31,   76,   14,   13,   15,
               0,   28,   28,   30,   48,   30,   48,   14,   48,    0,
              27,   48,    0,   27,   15,   36,   32,   16,   15,   30,
              16,    0,   14,   86,   78,   36,    0,   36,   34,   30,
              15,   76,   46,   28,   15,   24,   34,   26,   16,   14,
              48,   30,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp = 29 */

              14,   23,    2,   29,   49,    1,  125,  125,  125,    1,
               1,  125,    5,  125,  125,  125,    5,   28,  125,  125,
             125,  125,  125,  125,  125,  125,  125,  125,  125,  125,
             125,   14,   18,   18,   25,   29,    8,   18,   26,    1,
               2,    2,    9,    9,    4,   11,   13,   14,   11,   43,
              13,    6,   25,   61,   43,   25,   10,   22,   20,   28,
               9,    9,    4,   11,   13,   14,   11,   43,   13,    6,
              25,   61,   43,   25,   10,   22,   20,   28,   56,   35,
              82,   29,   25,   25,   11,    9,    9,    8,    4,   22,
               4,   38,   11,   29,   74,   14,   11,   38,   11,   29,
              74,   14,   11,   38,   11,   29,   74,   14,   11,   13,
               2,   26,   26,   30,   50,   30,   50,   14,   50,    2,
              25,   50,    2,   25,   13,   40,   34,   18,   13,   30,
              18,    2,   14,   90,   78,   40,    2,   38,   36,   30,
              13,   74,   44,   26,   13,   20,   36,   24,   18,   14,
              50,   28,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp = 30 */

              14,   25,    2,   29,   49,    1,  125,  125,  125,    1,
               1,  125,    5,  125,  125,  125,    5,   32,  125,  125,
             125,  125,  125,  125,  125,  125,  125,  125,  125,  125,
             125,   14,   18,   18,   23,   29,   10,   18,   26,    1,
               2,    2,    7,    7,    4,   11,   13,   14,   11,   43,
              13,    8,   23,   61,   43,   23,   12,   24,   20,   32,
               7,    7,    4,   11,   13,   14,   11,   43,   13,    8,
              23,   61,   43,   23,   12,   24,   20,   32,   58,   35,
              82,   29,   23,   23,   11,    7,    7,   10,    4,   24,
               4,   40,   11,   29,   74,   14,   11,   40,   11,   29,
              74,   14,   11,   40,   11,   29,   74,   14,   11,   13,
               2,   26,   26,   30,   50,   30,   50,   14,   50,    2,
              23,   50,    2,   23,   13,   42,   34,   18,   13,   30,
              18,    2,   14,   92,   78,   42,    2,   40,   36,   30,
              13,   74,   44,   26,   13,   18,   36,   22,   18,   14,
              50,   28,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp = 31 */

              14,   27,    2,   29,   49,    1,  125,  125,  125,    1,
               1,  125,    7,  125,  125,  125,    7,   36,  125,  125,
             125,  125,  125,  125,  125,  125,  125,  125,  125,  125,
             125,   14,   18,   18,   21,   29,   12,   18,   24,    1,
               2,    2,    5,    5,    6,    9,   13,   14,    9,   41,
              13,   10,   21,   61,   41,   21,   16,   26,   22,   36,
               5,    5,    6,    9,   13,   14,    9,   41,   13,   10,
              21,   61,   41,   21,   16,   26,   22,   36,   60,   35,
              82,   29,   21,   21,    9,    5,    5,   12,    6,   26,
               6,   42,    9,   29,   72,   14,    9,   42,    9,   29,
              72,   14,    9,   42,    9,   29,   72,   14,    9,   13,
               2,   24,   24,   30,   50,   30,   50,   14,   50,    2,
              21,   50,    2,   21,   13,   44,   34,   18,   13,   30,
              18,    2,   14,   96,   78,   44,    2,   42,   38,   30,
              13,   72,   44,   24,   13,   14,   38,   20,   18,   14,
              50,   28,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp = 32 */

              14,   29,    2,   29,   49,    1,  125,  125,  125,    1,
               1,  125,    9,  125,  125,  125,    9,   38,  125,  125,
             125,  125,  125,  125,  125,  125,  125,  125,  125,  125,
             125,   14,   18,   18,   21,   29,   14,   18,   22,    1,
               2,    2,    5,    5,    6,    9,   13,   14,    9,   41,
              13,   10,   21,   61,   41,   21,   18,   26,   22,   38,
               5,    5,    6,    9,   13,   14,    9,   41,   13,   10,
              21,   61,   41,   21,   18,   26,   22,   38,   62,   37,
              82,   29,   21,   21,    9,    5,    5,   14,    6,   26,
               6,   42,    9,   29,   70,   14,    9,   42,    9,   29,
              70,   14,    9,   42,    9,   29,   70,   14,    9,   13,
               2,   22,   22,   30,   50,   30,   50,   14,   50,    2,
              21,   50,    2,   21,   13,   46,   34,   18,   13,   30,
              18,    2,   14,   98,   78,   46,    2,   42,   38,   30,
              13,   70,   42,   22,   13,   10,   38,   18,   18,   14,
              50,   26,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp = 33 */

              14,   29,    4,   27,   49,    1,  125,  125,  125,    1,
               1,  125,    9,  125,  125,  125,    9,   42,  125,  125,
             125,  125,  125,  125,  125,  125,  125,  125,  125,  125,
             125,   14,   20,   20,   19,   27,   18,   20,   22,    1,
               4,    4,    3,    3,    8,    7,   11,   14,    7,   39,
              11,   12,   19,   59,   39,   19,   22,   28,   24,   42,
               3,    3,    8,    7,   11,   14,    7,   39,   11,   12,
              19,   59,   39,   19,   22,   28,   24,   42,   66,   37,
              84,   27,   19,   19,    7,    3,    3,   18,    8,   28,
               8,   44,    7,   27,   70,   14,    7,   44,    7,   27,
              70,   14,    7,   44,    7,   27,   70,   14,    7,   11,
               4,   22,   22,   30,   52,   30,   52,   14,   52,    4,
              19,   52,    4,   19,   11,   50,   36,   20,   11,   30,
              20,    4,   14,  102,   78,   50,    4,   44,   40,   30,
              11,   70,   42,   22,   11,    8,   40,   18,   20,   14,
              52,   26,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp = 34 */

              14,   31,    4,   27,   49,    1,  125,  125,  125,    1,
               1,  125,   11,  125,  125,  125,   11,   46,  125,  125,
             125,  125,  125,  125,  125,  125,  125,  125,  125,  125,
             125,   14,   20,   20,   17,   27,   20,   20,   20,    1,
               4,    4,    1,    1,   10,    5,   11,   14,    5,   37,
              11,   14,   17,   59,   37,   17,   26,   30,   26,   46,
               1,    1,   10,    5,   11,   14,    5,   37,   11,   14,
              17,   59,   37,   17,   26,   30,   26,   46,   68,   37,
              84,   27,   17,   17,    5,    1,    1,   20,   10,   30,
              10,   46,    5,   27,   68,   14,    5,   46,    5,   27,
              68,   14,    5,   46,    5,   27,   68,   14,    5,   11,
               4,   20,   20,   30,   52,   30,   52,   14,   52,    4,
              17,   52,    4,   17,   11,   52,   36,   20,   11,   30,
              20,    4,   14,  106,   78,   52,    4,   46,   42,   30,
              11,   68,   42,   20,   11,    4,   42,   16,   20,   14,
              52,   26,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp = 35 */

              14,   33,    4,   27,   49,    1,  125,  125,  125,    1,
               1,  125,   11,  125,  125,  125,   11,   50,  125,  125,
             125,  125,  125,  125,  125,  125,  125,  125,  125,  125,
             125,   14,   20,   20,   15,   27,   22,   20,   20,    1,
               4,    4,    0,    0,   10,    5,   11,   14,    5,   37,
              11,   16,   15,   59,   37,   15,   28,   32,   26,   50,
               0,    0,   10,    5,   11,   14,    5,   37,   11,   16,
              15,   59,   37,   15,   28,   32,   26,   50,   70,   37,
              84,   27,   15,   15,    5,    0,    0,   22,   10,   32,
              10,   48,    5,   27,   68,   14,    5,   48,    5,   27,
              68,   14,    5,   48,    5,   27,   68,   14,    5,   11,
               4,   20,   20,   30,   52,   30,   52,   14,   52,    4,
              15,   52,    4,   15,   11,   54,   36,   20,   11,   30,
              20,    4,   14,  108,   78,   54,    4,   48,   42,   30,
              11,   68,   42,   20,   11,    2,   42,   14,   20,   14,
              52,   26,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp = 36 */

              14,   35,    6,   25,   49,    1,  125,  125,  125,    1,
               1,  125,   13,  125,  125,  125,   13,   54,  125,  125,
             125,  125,  125,  125,  125,  125,  125,  125,  125,  125,
             125,   14,   22,   22,   13,   25,   24,   22,   18,    1,
               6,    6,    2,    2,   12,    3,    9,   14,    3,   35,
               9,   18,   13,   57,   35,   13,   32,   34,   28,   54,
               2,    2,   12,    3,    9,   14,    3,   35,    9,   18,
              13,   57,   35,   13,   32,   34,   28,   54,   72,   39,
              86,   25,   13,   13,    3,    2,    2,   24,   12,   34,
              12,   50,    3,   25,   66,   14,    3,   50,    3,   25,
              66,   14,    3,   50,    3,   25,   66,   14,    3,    9,
               6,   18,   18,   30,   54,   30,   54,   14,   54,    6,
              13,   54,    6,   13,    9,   56,   38,   22,    9,   30,
              22,    6,   14,  112,   78,   56,    6,   50,   44,   30,
               9,   66,   40,   18,    9,    1,   44,   12,   22,   14,
              54,   24,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp = 37 */

              14,   37,    6,   25,   49,    1,  125,  125,  125,    1,
               1,  125,   15,  125,  125,  125,   15,   58,  125,  125,
             125,  125,  125,  125,  125,  125,  125,  125,  125,  125,
             125,   14,   22,   22,   11,   25,   28,   22,   16,    1,
               6,    6,    4,    4,   14,    1,    9,   14,    1,   33,
               9,   20,   11,   57,   33,   11,   34,   36,   30,   58,
               4,    4,   14,    1,    9,   14,    1,   33,    9,   20,
              11,   57,   33,   11,   34,   36,   30,   58,   76,   39,
              86,   25,   11,   11,    1,    4,    4,   28,   14,   36,
              14,   52,    1,   25,   64,   14,    1,   52,    1,   25,
              64,   14,    1,   52,    1,   25,   64,   14,    1,    9,
               6,   16,   16,   30,   54,   30,   54,   14,   54,    6,
              11,   54,    6,   11,    9,   60,   38,   22,    9,   30,
              22,    6,   14,  114,   78,   60,    6,   52,   46,   30,
               9,   64,   40,   16,    9,    3,   46,   10,   22,   14,
              54,   24,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp = 38 */

              14,   39,    6,   25,   49,    1,  125,  125,  125,    1,
               1,  125,   15,  125,  125,  125,   15,   62,  125,  125,
             125,  125,  125,  125,  125,  125,  125,  125,  125,  125,
             125,   14,   22,   22,    9,   25,   30,   22,   16,    1,
               6,    6,    6,    6,   14,    1,    9,   14,    1,   33,
               9,   22,    9,   57,   33,    9,   38,   38,   30,   62,
               6,    6,   14,    1,    9,   14,    1,   33,    9,   22,
               9,   57,   33,    9,   38,   38,   30,   62,   78,   39,
              86,   25,    9,    9,    1,    6,    6,   30,   14,   38,
              14,   54,    1,   25,   64,   14,    1,   54,    1,   25,
              64,   14,    1,   54,    1,   25,   64,   14,    1,    9,
               6,   16,   16,   30,   54,   30,   54,   14,   54,    6,
               9,   54,    6,    9,    9,   62,   38,   22,    9,   30,
              22,    6,   14,  118,   78,   62,    6,   54,   46,   30,
               9,   64,   40,   16,    9,    7,   46,    8,   22,   14,
              54,   24,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp = 39 */

              14,   41,    8,   23,   49,    1,  125,  125,  125,    1,
               1,  125,   17,  125,  125,  125,   17,   66,  125,  125,
             125,  125,  125,  125,  125,  125,  125,  125,  125,  125,
             125,   14,   24,   24,    7,   23,   32,   24,   14,    1,
               8,    8,    8,    8,   16,    0,    7,   14,    0,   31,
               7,   24,    7,   55,   31,    7,   40,   40,   32,   66,
               8,    8,   16,    0,    7,   14,    0,   31,    7,   24,
               7,   55,   31,    7,   40,   40,   32,   66,   80,   41,
              88,   23,    7,    7,    0,    8,    8,   32,   16,   40,
              16,   56,    0,   23,   62,   14,    0,   56,    0,   23,
              62,   14,    0,   56,    0,   23,   62,   14,    0,    7,
               8,   14,   14,   30,   56,   30,   56,   14,   56,    8,
               7,   56,    8,    7,    7,   64,   40,   24,    7,   30,
              24,    8,   14,  120,   78,   64,    8,   56,   48,   30,
               7,   62,   38,   14,    7,    9,   48,    6,   24,   14,
              56,   22,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp = 40 */

              14,   43,    8,   23,   49,    1,  125,  125,  125,    1,
               1,  125,   19,  125,  125,  125,   19,   68,  125,  125,
             125,  125,  125,  125,  125,  125,  125,  125,  125,  125,
             125,   14,   24,   24,    5,   23,   34,   24,   12,    1,
               8,    8,   10,   10,   16,    0,    7,   14,    0,   31,
               7,   26,    5,   55,   31,    5,   44,   42,   32,   68,
              10,   10,   16,    0,    7,   14,    0,   31,    7,   26,
               5,   55,   31,    5,   44,   42,   32,   68,   82,   41,
              88,   23,    5,    5,    0,   10,   10,   34,   16,   42,
              16,   58,    0,   23,   60,   14,    0,   58,    0,   23,
              60,   14,    0,   58,    0,   23,   60,   14,    0,    7,
               8,   12,   12,   30,   56,   30,   56,   14,   56,    8,
               5,   56,    8,    5,    7,   66,   40,   24,    7,   30,
              24,    8,   14,  124,   78,   66,    8,   58,   48,   30,
               7,   60,   38,   12,    7,   13,   48,    4,   24,   14,
              56,   22,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp = 41 */

              14,   45,    8,   23,   49,    1,  125,  125,  125,    1,
               1,  125,   19,  125,  125,  125,   19,   72,  125,  125,
             125,  125,  125,  125,  125,  125,  125,  125,  125,  125,
             125,   14,   24,   24,    3,   23,   38,   24,   12,    1,
               8,    8,   12,   12,   18,    2,    7,   14,    2,   29,
               7,   28,    3,   55,   29,    3,   48,   44,   34,   72,
              12,   12,   18,    2,    7,   14,    2,   29,    7,   28,
               3,   55,   29,    3,   48,   44,   34,   72,   86,   41,
              88,   23,    3,    3,    2,   12,   12,   38,   18,   44,
              18,   60,    2,   23,   60,   14,    2,   60,    2,   23,
              60,   14,    2,   60,    2,   23,   60,   14,    2,    7,
               8,   12,   12,   30,   56,   30,   56,   14,   56,    8,
               3,   56,    8,    3,    7,   70,   40,   24,    7,   30,
              24,    8,   14,  124,   78,   70,    8,   60,   50,   30,
               7,   60,   38,   12,    7,   17,   50,    2,   24,   14,
              56,   22,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp = 42 */

              14,   47,   10,   21,   49,    1,  125,  125,  125,    1,
               1,  125,   21,  125,  125,  125,   21,   76,  125,  125,
             125,  125,  125,  125,  125,  125,  125,  125,  125,  125,
             125,   14,   26,   26,    1,   21,   40,   26,   10,    1,
              10,   10,   14,   14,   20,    4,    5,   14,    4,   27,
               5,   30,    1,   53,   27,    1,   50,   46,   36,   76,
              14,   14,   20,    4,    5,   14,    4,   27,    5,   30,
               1,   53,   27,    1,   50,   46,   36,   76,   88,   43,
              90,   21,    1,    1,    4,   14,   14,   40,   20,   46,
              20,   62,    4,   21,   58,   14,    4,   62,    4,   21,
              58,   14,    4,   62,    4,   21,   58,   14,    4,    5,
              10,   10,   10,   30,   58,   30,   58,   14,   58,   10,
               1,   58,   10,    1,    5,   72,   42,   26,    5,   30,
              26,   10,   14,  124,   78,   72,   10,   62,   52,   30,
               5,   58,   36,   10,    5,   19,   52,    0,   26,   14,
              58,   20,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp = 43 */

              14,   49,   10,   21,   49,    1,  125,  125,  125,    1,
               1,  125,   21,  125,  125,  125,   21,   80,  125,  125,
             125,  125,  125,  125,  125,  125,  125,  125,  125,  125,
             125,   14,   26,   26,    0,   21,   42,   26,   10,    1,
              10,   10,   16,   16,   20,    4,    5,   14,    4,   27,
               5,   32,    0,   53,   27,    0,   54,   48,   36,   80,
              16,   16,   20,    4,    5,   14,    4,   27,    5,   32,
               0,   53,   27,    0,   54,   48,   36,   80,   90,   43,
              90,   21,    0,    0,    4,   16,   16,   42,   20,   48,
              20,   64,    4,   21,   58,   14,    4,   64,    4,   21,
              58,   14,    4,   64,    4,   21,   58,   14,    4,    5,
              10,   10,   10,   30,   58,   30,   58,   14,   58,   10,
               0,   58,   10,    0,    5,   74,   42,   26,    5,   30,
              26,   10,   14,  124,   78,   74,   10,   64,   52,   30,
               5,   58,   36,   10,    5,   23,   52,    1,   26,   14,
              58,   20,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp = 44 */

              14,   51,   10,   21,   49,    1,  125,  125,  125,    1,
               1,  125,   23,  125,  125,  125,   23,   84,  125,  125,
             125,  125,  125,  125,  125,  125,  125,  125,  125,  125,
             125,   14,   26,   26,    2,   21,   44,   26,    8,    1,
              10,   10,   18,   18,   22,    6,    5,   14,    6,   25,
               5,   34,    2,   53,   25,    2,   56,   50,   38,   84,
              18,   18,   22,    6,    5,   14,    6,   25,    5,   34,
               2,   53,   25,    2,   56,   50,   38,   84,   92,   43,
              90,   21,    2,    2,    6,   18,   18,   44,   22,   50,
              22,   66,    6,   21,   56,   14,    6,   66,    6,   21,
              56,   14,    6,   66,    6,   21,   56,   14,    6,    5,
              10,    8,    8,   30,   58,   30,   58,   14,   58,   10,
               2,   58,   10,    2,    5,   76,   42,   26,    5,   30,
              26,   10,   14,  124,   78,   76,   10,   66,   54,   30,
               5,   56,   36,    8,    5,   25,   54,    3,   26,   14,
              58,   20,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp = 45 */

              14,   53,   12,   19,   49,    1,  125,  125,  125,    1,
               1,  125,   25,  125,  125,  125,   25,   88,  125,  125,
             125,  125,  125,  125,  125,  125,  125,  125,  125,  125,
             125,   14,   28,   28,    4,   19,   48,   28,    6,    1,
              12,   12,   20,   20,   24,    8,    3,   14,    8,   23,
               3,   36,    4,   51,   23,    4,   60,   52,   40,   88,
              20,   20,   24,    8,    3,   14,    8,   23,    3,   36,
               4,   51,   23,    4,   60,   52,   40,   88,   96,   45,
              92,   19,    4,    4,    8,   20,   20,   48,   24,   52,
              24,   68,    8,   19,   54,   14,    8,   68,    8,   19,
              54,   14,    8,   68,    8,   19,   54,   14,    8,    3,
              12,    6,    6,   30,   60,   30,   60,   14,   60,   12,
               4,   60,   12,    4,    3,   80,   44,   28,    3,   30,
              28,   12,   14,  124,   78,   80,   12,   68,   56,   30,
               3,   54,   34,    6,    3,   29,   56,    5,   28,   14,
              60,   18,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp = 46 */

              14,   55,   12,   19,   49,    1,  125,  125,  125,    1,
               1,  125,   25,  125,  125,  125,   25,   92,  125,  125,
             125,  125,  125,  125,  125,  125,  125,  125,  125,  125,
             125,   14,   28,   28,    6,   19,   50,   28,    6,    1,
              12,   12,   22,   22,   24,    8,    3,   14,    8,   23,
               3,   38,    6,   51,   23,    6,   62,   54,   40,   92,
              22,   22,   24,    8,    3,   14,    8,   23,    3,   38,
               6,   51,   23,    6,   62,   54,   40,   92,   98,   45,
              92,   19,    6,    6,    8,   22,   22,   50,   24,   54,
              24,   70,    8,   19,   54,   14,    8,   70,    8,   19,
              54,   14,    8,   70,    8,   19,   54,   14,    8,    3,
              12,    6,    6,   30,   60,   30,   60,   14,   60,   12,
               6,   60,   12,    6,    3,   82,   44,   28,    3,   30,
              28,   12,   14,  124,   78,   82,   12,   70,   56,   30,
               3,   54,   34,    6,    3,   31,   56,    7,   28,   14,
              60,   18,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp = 47 */

              14,   57,   12,   19,   49,    1,  125,  125,  125,    1,
               1,  125,   27,  125,  125,  125,   27,   96,  125,  125,
             125,  125,  125,  125,  125,  125,  125,  125,  125,  125,
             125,   14,   28,   28,    8,   19,   52,   28,    4,    1,
              12,   12,   24,   24,   26,   10,    3,   14,   10,   21,
               3,   40,    8,   51,   21,    8,   66,   56,   42,   96,
              24,   24,   26,   10,    3,   14,   10,   21,    3,   40,
               8,   51,   21,    8,   66,   56,   42,   96,  100,   45,
              92,   19,    8,    8,   10,   24,   24,   52,   26,   56,
              26,   72,   10,   19,   52,   14,   10,   72,   10,   19,
              52,   14,   10,   72,   10,   19,   52,   14,   10,    3,
              12,    4,    4,   30,   60,   30,   60,   14,   60,   12,
               8,   60,   12,    8,    3,   84,   44,   28,    3,   30,
              28,   12,   14,  124,   78,   84,   12,   72,   58,   30,
               3,   52,   34,    4,    3,   35,   58,    9,   28,   14,
              60,   18,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp = 48 */

              14,   59,   12,   19,   49,    1,  125,  125,  125,    1,
               1,  125,   29,  125,  125,  125,   29,   98,  125,  125,
             125,  125,  125,  125,  125,  125,  125,  125,  125,  125,
             125,   14,   28,   28,    8,   19,   54,   28,    2,    1,
              12,   12,   24,   24,   26,   10,    3,   14,   10,   21,
               3,   40,    8,   51,   21,    8,   68,   56,   42,   98,
              24,   24,   26,   10,    3,   14,   10,   21,    3,   40,
               8,   51,   21,    8,   68,   56,   42,   98,  102,   47,
              92,   19,    8,    8,   10,   24,   24,   54,   26,   56,
              26,   72,   10,   19,   50,   14,   10,   72,   10,   19,
              50,   14,   10,   72,   10,   19,   50,   14,   10,    3,
              12,    2,    2,   30,   60,   30,   60,   14,   60,   12,
               8,   60,   12,    8,    3,   86,   44,   28,    3,   30,
              28,   12,   14,  124,   78,   86,   12,   72,   58,   30,
               3,   50,   32,    2,    3,   39,   58,   11,   28,   14,
              60,   16,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp = 49 */

              14,   59,   14,   17,   49,    1,  125,  125,  125,    1,
               1,  125,   29,  125,  125,  125,   29,  102,  125,  125,
             125,  125,  125,  125,  125,  125,  125,  125,  125,  125,
             125,   14,   30,   30,   10,   17,   58,   30,    2,    1,
              14,   14,   26,   26,   28,   12,    1,   14,   12,   19,
               1,   42,   10,   49,   19,   10,   72,   58,   44,  102,
              26,   26,   28,   12,    1,   14,   12,   19,    1,   42,
              10,   49,   19,   10,   72,   58,   44,  102,  106,   47,
              94,   17,   10,   10,   12,   26,   26,   58,   28,   58,
              28,   74,   12,   17,   50,   14,   12,   74,   12,   17,
              50,   14,   12,   74,   12,   17,   50,   14,   12,    1,
              14,    2,    2,   30,   62,   30,   62,   14,   62,   14,
              10,   62,   14,   10,    1,   90,   46,   30,    1,   30,
              30,   14,   14,  124,   78,   90,   14,   74,   60,   30,
               1,   50,   32,    2,    1,   41,   60,   11,   30,   14,
              62,   16,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp = 50 */

              14,   61,   14,   17,   49,    1,  125,  125,  125,    1,
               1,  125,   31,  125,  125,  125,   31,  106,  125,  125,
             125,  125,  125,  125,  125,  125,  125,  125,  125,  125,
             125,   14,   30,   30,   12,   17,   60,   30,    0,    1,
              14,   14,   28,   28,   30,   14,    1,   14,   14,   17,
               1,   44,   12,   49,   17,   12,   76,   60,   46,  106,
              28,   28,   30,   14,    1,   14,   14,   17,    1,   44,
              12,   49,   17,   12,   76,   60,   46,  106,  108,   47,
              94,   17,   12,   12,   14,   28,   28,   60,   30,   60,
              30,   76,   14,   17,   48,   14,   14,   76,   14,   17,
              48,   14,   14,   76,   14,   17,   48,   14,   14,    1,
              14,    0,    0,   30,   62,   30,   62,   14,   62,   14,
              12,   62,   14,   12,    1,   92,   46,   30,    1,   30,
              30,   14,   14,  124,   78,   92,   14,   76,   62,   30,
               1,   48,   32,    0,    1,   45,   62,   13,   30,   14,
              62,   16,   30,   30,
        },

        {
            /* Context Tables for init_idc = 0, qp = 51 */

              14,   63,   14,   17,   49,    1,  125,  125,  125,    1,
               1,  125,   31,  125,  125,  125,   31,  110,  125,  125,
             125,  125,  125,  125,  125,  125,  125,  125,  125,  125,
             125,   14,   30,   30,   14,   17,   62,   30,    0,    1,
              14,   14,   30,   30,   30,   14,    1,   14,   14,   17,
               1,   46,   14,   49,   17,   14,   78,   62,   46,  110,
              30,   30,   30,   14,    1,   14,   14,   17,    1,   46,
              14,   49,   17,   14,   78,   62,   46,  110,  110,   47,
              94,   17,   14,   14,   14,   30,   30,   62,   30,   62,
              30,   78,   14,   17,   48,   14,   14,   78,   14,   17,
              48,   14,   14,   78,   14,   17,   48,   14,   14,    1,
              14,    0,    0,   30,   62,   30,   62,   14,   62,   14,
              14,   62,   14,   14,    1,   94,   46,   30,    1,   30,
              30,   14,   14,  124,   78,   94,   14,   78,   62,   30,
               1,   48,   32,    0,    1,   47,   62,   15,   30,   14,
              62,   16,   30,   30,
        },

    },

    {
        {
            /* Context Tables for init_idc = 1, qp =  0 */

              14,   14,   17,   17,   65,    1,   78,   14,   14,    1,
               1,   78,    1,   17,    1,    1,    1,   30,   65,    1,
              81,   81,   81,   81,   81,   14,   14,   33,   62,   30,
              81,   33,    1,   65,   14,   81,   78,   17,   46,    1,
              17,   17,   49,   65,   65,   65,   81,   81,   49,   81,
              65,   65,   65,   81,   81,   81,   65,   33,   17,   33,
              49,   65,   65,   65,   81,   81,   49,   81,   65,   65,
              65,   81,   81,   81,   65,   33,   17,   33,   14,   33,
              49,    1,   17,    1,   17,   14,   17,   17,   17,   81,
              14,   62,   46,   33,   30,   14,    1,   62,   46,   33,
              30,   14,    1,   62,   46,   33,   30,   14,    1,    1,
              14,   17,   17,   17,   14,   17,   14,   46,   46,   46,
              33,   46,   46,   33,    1,   94,   94,   46,    1,   30,
              46,   62,   62,   62,   78,   30,   14,   14,   30,   14,
              14,  124,   62,   46,    1,   46,   14,   62,   17,   46,
              17,    1,   17,   46,
        },

        {
            /* Context Tables for init_idc = 1, qp =  1 */

              14,   14,   15,   15,   63,    1,   78,   14,   14,    1,
               1,   78,    1,   15,    1,    1,    1,   30,   63,    0,
              77,   77,   77,   75,   75,   14,   14,   31,   62,   30,
              77,   31,    0,   61,   14,   79,   78,   15,   46,    1,
              15,   15,   47,   63,   61,   63,   77,   77,   47,   79,
              63,   61,   63,   79,   79,   77,   61,   31,   15,   31,
              47,   63,   61,   63,   77,   77,   47,   79,   63,   61,
              63,   79,   79,   77,   61,   31,   15,   31,   16,   31,
              45,    1,   17,    1,   15,   14,   15,   15,   15,   77,
              14,   62,   46,   31,   32,   14,    1,   62,   46,   31,
              32,   14,    1,   62,   46,   31,   32,   14,    1,    1,
              14,   15,   15,   15,   16,   15,   16,   46,   46,   46,
              31,   46,   46,   31,    1,   94,   94,   46,    1,   30,
              46,   62,   62,   64,   78,   32,   14,   16,   32,   16,
              14,  124,   62,   46,    1,   46,   16,   62,   15,   46,
              13,    0,   15,   46,
        },

        {
            /* Context Tables for init_idc = 1, qp =  2 */

              14,   12,   13,   15,   61,    1,   76,   12,   12,    1,
               1,   78,    1,   15,    1,    1,    1,   30,   61,    2,
              75,   73,   73,   71,   71,   14,   14,   31,   60,   30,
              73,   29,    0,   59,   14,   77,   78,   13,   46,    1,
              15,   15,   45,   61,   59,   61,   75,   73,   45,   77,
              61,   57,   61,   77,   77,   75,   59,   29,   13,   29,
              45,   61,   59,   61,   75,   73,   45,   77,   61,   57,
              61,   77,   77,   75,   59,   29,   13,   29,   18,   31,
              41,    1,   17,    1,   15,   14,   15,   13,   13,   73,
              14,   62,   44,   31,   32,   14,    1,   62,   44,   31,
              32,   14,    1,   62,   44,   31,   32,   14,    1,    1,
              14,   13,   13,   13,   18,   13,   18,   46,   46,   44,
              31,   46,   44,   31,    1,   92,   92,   46,    1,   30,
              46,   60,   60,   64,   78,   32,   14,   18,   32,   16,
              14,  124,   62,   46,    1,   46,   16,   60,   13,   46,
              11,    2,   13,   46,
        },

        {
            /* Context Tables for init_idc = 1, qp =  3 */

              14,   12,   11,   15,   61,    1,   74,   12,   10,    1,
               1,   78,    1,   15,    1,    1,    1,   30,   59,    2,
              73,   71,   69,   65,   65,   14,   14,   31,   58,   30,
              71,   29,    0,   57,   14,   75,   78,   11,   46,    1,
              15,   15,   45,   59,   57,   59,   73,   71,   45,   75,
              59,   55,   59,   75,   75,   73,   57,   27,   13,   27,
              45,   59,   57,   59,   73,   71,   45,   75,   59,   55,
              59,   75,   75,   73,   57,   27,   13,   27,   18,   31,
              37,    1,   17,    1,   15,   14,   15,   13,   13,   69,
              14,   62,   44,   31,   32,   14,    1,   62,   44,   31,
              32,   14,    1,   62,   44,   31,   32,   14,    1,    1,
              14,   13,   13,   11,   18,   11,   18,   46,   46,   44,
              31,   46,   44,   31,    1,   90,   90,   46,    1,   30,
              46,   60,   60,   64,   78,   32,   14,   18,   32,   16,
              14,  122,   62,   46,    1,   46,   16,   60,   11,   46,
               9,    2,   11,   46,
        },

        {
            /* Context Tables for init_idc = 1, qp =  4 */

              14,   10,    9,   13,   59,    1,   72,   10,    8,    1,
               1,   78,    1,   13,    1,    1,    1,   30,   57,    4,
              71,   67,   65,   61,   61,   14,   14,   29,   56,   28,
              67,   27,    2,   55,   14,   73,   78,    9,   44,    1,
              13,   13,   43,   57,   55,   57,   71,   67,   43,   73,
              57,   51,   57,   73,   73,   71,   55,   25,   11,   25,
              43,   57,   55,   57,   71,   67,   43,   73,   57,   51,
              57,   73,   73,   71,   55,   25,   11,   25,   20,   29,
              33,    1,   17,    1,   13,   14,   13,   11,   11,   65,
              14,   60,   42,   29,   34,   14,    1,   60,   42,   29,
              34,   14,    1,   60,   42,   29,   34,   14,    1,    3,
              14,   11,   11,    9,   20,    9,   20,   44,   46,   42,
              29,   46,   42,   29,    1,   88,   88,   44,    1,   30,
              44,   58,   58,   66,   78,   34,   14,   20,   34,   18,
              12,  120,   60,   44,    1,   44,   18,   58,    9,   44,
               7,    4,    9,   44,
        },

        {
            /* Context Tables for init_idc = 1, qp =  5 */

              14,    8,    7,   13,   57,    1,   70,    8,    6,    1,
               1,   78,    1,   13,    1,    1,    1,   30,   55,    6,
              67,   65,   61,   55,   55,   14,   14,   29,   54,   28,
              65,   25,    2,   51,   14,   71,   78,    7,   44,    1,
              13,   13,   41,   55,   51,   55,   67,   65,   41,   71,
              55,   49,   55,   71,   71,   67,   51,   23,    9,   23,
              41,   55,   51,   55,   67,   65,   41,   71,   55,   49,
              55,   71,   71,   67,   51,   23,    9,   23,   22,   29,
              29,    1,   17,    1,   13,   14,   13,    9,    9,   61,
              14,   60,   40,   29,   34,   14,    1,   60,   40,   29,
              34,   14,    1,   60,   40,   29,   34,   14,    1,    3,
              14,    9,    9,    7,   22,    7,   22,   44,   46,   40,
              29,   46,   40,   29,    1,   86,   86,   44,    1,   30,
              44,   56,   56,   66,   78,   34,   14,   22,   34,   18,
              12,  118,   60,   44,    1,   44,   18,   56,    7,   44,
               3,    6,    7,   44,
        },

        {
            /* Context Tables for init_idc = 1, qp =  6 */

              14,    8,    5,   13,   57,    1,   68,    8,    4,    1,
               1,   78,    1,   13,    1,    1,    1,   30,   53,    6,
              65,   61,   57,   51,   51,   14,   14,   29,   52,   28,
              61,   25,    2,   49,   14,   69,   78,    5,   44,    1,
              13,   13,   41,   53,   49,   53,   65,   61,   41,   69,
              53,   45,   53,   69,   69,   65,   49,   21,    9,   21,
              41,   53,   49,   53,   65,   61,   41,   69,   53,   45,
              53,   69,   69,   65,   49,   21,    9,   21,   22,   29,
              25,    1,   17,    1,   13,   14,   13,    9,    9,   57,
              14,   60,   40,   29,   34,   14,    1,   60,   40,   29,
              34,   14,    1,   60,   40,   29,   34,   14,    1,    3,
              14,    9,    9,    5,   22,    5,   22,   44,   46,   40,
              29,   46,   40,   29,    1,   84,   84,   44,    1,   30,
              44,   56,   56,   66,   78,   34,   14,   22,   34,   18,
              12,  116,   60,   44,    1,   44,   18,   56,    5,   44,
               1,    6,    5,   44,
        },

        {
            /* Context Tables for init_idc = 1, qp =  7 */

              14,    6,    3,   11,   55,    1,   66,    6,    2,    1,
               1,   78,    1,   11,    1,    1,    1,   30,   51,    8,
              63,   59,   53,   45,   45,   14,   14,   27,   50,   26,
              59,   23,    4,   47,   14,   67,   78,    3,   42,    1,
              11,   11,   39,   51,   47,   51,   63,   59,   39,   67,
              51,   43,   51,   67,   67,   63,   47,   19,    7,   19,
              39,   51,   47,   51,   63,   59,   39,   67,   51,   43,
              51,   67,   67,   63,   47,   19,    7,   19,   24,   27,
              21,    1,   17,    1,   11,   14,   11,    7,    7,   53,
              14,   58,   38,   27,   36,   14,    1,   58,   38,   27,
              36,   14,    1,   58,   38,   27,   36,   14,    1,    5,
              14,    7,    7,    3,   24,    3,   24,   42,   46,   38,
              27,   46,   38,   27,    1,   82,   82,   42,    1,   30,
              42,   54,   54,   68,   78,   36,   14,   24,   36,   20,
              10,  114,   58,   42,    1,   42,   20,   54,    3,   42,
               0,    8,    3,   42,
        },

        {
            /* Context Tables for init_idc = 1, qp =  8 */

              14,    4,    1,   11,   55,    1,   64,    4,    0,    1,
               1,   78,    1,   11,    1,    1,    1,   30,   49,    8,
              61,   55,   51,   41,   41,   14,   14,   27,   48,   26,
              55,   23,    4,   45,   14,   65,   78,    1,   42,    1,
              11,   11,   39,   49,   45,   49,   61,   55,   39,   65,
              49,   39,   49,   65,   65,   61,   45,   17,    7,   17,
              39,   49,   45,   49,   61,   55,   39,   65,   49,   39,
              49,   65,   65,   61,   45,   17,    7,   17,   24,   27,
              19,    1,   17,    1,   11,   14,   11,    7,    7,   51,
              14,   58,   36,   27,   36,   14,    1,   58,   36,   27,
              36,   14,    1,   58,   36,   27,   36,   14,    1,    5,
              14,    7,    7,    1,   24,    1,   24,   42,   46,   36,
              27,   46,   36,   27,    1,   80,   80,   42,    1,   30,
              42,   52,   52,   68,   78,   36,   14,   24,   36,   20,
              10,  112,   58,   42,    1,   42,   20,   52,    1,   42,
               2,    8,    1,   42,
        },

        {
            /* Context Tables for init_idc = 1, qp =  9 */

              14,    4,    0,   11,   53,    1,   62,    4,    1,    1,
               1,   78,    1,   11,    1,    1,    1,   30,   47,   10,
              57,   51,   47,   35,   35,   14,   14,   27,   46,   26,
              51,   21,    4,   41,   14,   63,   78,    0,   42,    1,
              11,   11,   37,   47,   41,   47,   57,   51,   37,   63,
              47,   35,   47,   63,   63,   57,   41,   15,    5,   15,
              37,   47,   41,   47,   57,   51,   37,   63,   47,   35,
              47,   63,   63,   57,   41,   15,    5,   15,   26,   27,
              15,    1,   17,    1,   11,   14,   11,    5,    5,   47,
              14,   58,   36,   27,   36,   14,    1,   58,   36,   27,
              36,   14,    1,   58,   36,   27,   36,   14,    1,    5,
              14,    5,    5,    0,   26,    0,   26,   42,   46,   36,
              27,   46,   36,   27,    1,   78,   78,   42,    1,   30,
              42,   52,   52,   68,   78,   36,   14,   26,   36,   20,
              10,  110,   58,   42,    1,   42,   20,   52,    0,   42,
               6,   10,    0,   42,
        },

        {
            /* Context Tables for init_idc = 1, qp = 10 */

              14,    2,    2,    9,   51,    1,   60,    2,    3,    1,
               1,   78,    1,    9,    1,    1,    1,   30,   45,   12,
              55,   49,   43,   31,   31,   14,   14,   25,   44,   24,
              49,   19,    6,   39,   14,   61,   78,    2,   40,    1,
               9,    9,   35,   45,   39,   45,   55,   49,   35,   61,
              45,   33,   45,   61,   61,   55,   39,   13,    3,   13,
              35,   45,   39,   45,   55,   49,   35,   61,   45,   33,
              45,   61,   61,   55,   39,   13,    3,   13,   28,   25,
              11,    1,   17,    1,    9,   14,    9,    3,    3,   43,
              14,   56,   34,   25,   38,   14,    1,   56,   34,   25,
              38,   14,    1,   56,   34,   25,   38,   14,    1,    7,
              14,    3,    3,    2,   28,    2,   28,   40,   46,   34,
              25,   46,   34,   25,    1,   76,   76,   40,    1,   30,
              40,   50,   50,   70,   78,   38,   14,   28,   38,   22,
               8,  108,   56,   40,    1,   40,   22,   50,    2,   40,
               8,   12,    2,   40,
        },

        {
            /* Context Tables for init_idc = 1, qp = 11 */

              14,    2,    4,    9,   51,    1,   58,    2,    5,    1,
               1,   78,    1,    9,    1,    1,    1,   30,   43,   12,
              53,   45,   39,   25,   25,   14,   14,   25,   42,   24,
              45,   19,    6,   37,   14,   59,   78,    4,   40,    1,
               9,    9,   35,   43,   37,   43,   53,   45,   35,   59,
              43,   29,   43,   59,   59,   53,   37,   11,    3,   11,
              35,   43,   37,   43,   53,   45,   35,   59,   43,   29,
              43,   59,   59,   53,   37,   11,    3,   11,   28,   25,
               7,    1,   17,    1,    9,   14,    9,    3,    3,   39,
              14,   56,   34,   25,   38,   14,    1,   56,   34,   25,
              38,   14,    1,   56,   34,   25,   38,   14,    1,    7,
              14,    3,    3,    4,   28,    4,   28,   40,   46,   34,
              25,   46,   34,   25,    1,   74,   74,   40,    1,   30,
              40,   50,   50,   70,   78,   38,   14,   28,   38,   22,
               8,  106,   56,   40,    1,   40,   22,   50,    4,   40,
              10,   12,    4,   40,
        },

        {
            /* Context Tables for init_idc = 1, qp = 12 */

              14,    0,    6,    9,   49,    1,   56,    0,    7,    1,
               1,   78,    1,    9,    1,    1,    1,   30,   41,   14,
              51,   43,   35,   21,   21,   14,   14,   25,   40,   24,
              43,   17,    6,   35,   14,   57,   78,    6,   40,    1,
               9,    9,   33,   41,   35,   41,   51,   43,   33,   57,
              41,   27,   41,   57,   57,   51,   35,    9,    1,    9,
              33,   41,   35,   41,   51,   43,   33,   57,   41,   27,
              41,   57,   57,   51,   35,    9,    1,    9,   30,   25,
               3,    1,   17,    1,    9,   14,    9,    1,    1,   35,
              14,   56,   32,   25,   38,   14,    1,   56,   32,   25,
              38,   14,    1,   56,   32,   25,   38,   14,    1,    7,
              14,    1,    1,    6,   30,    6,   30,   40,   46,   32,
              25,   46,   32,   25,    1,   72,   72,   40,    1,   30,
              40,   48,   48,   70,   78,   38,   14,   30,   38,   22,
               8,  104,   56,   40,    1,   40,   22,   48,    6,   40,
              12,   14,    6,   40,
        },

        {
            /* Context Tables for init_idc = 1, qp = 13 */

              14,    1,    8,    7,   47,    1,   54,    1,    9,    1,
               1,   78,    1,    7,    1,    1,    1,   30,   39,   16,
              47,   39,   31,   15,   15,   14,   14,   23,   38,   22,
              39,   15,    8,   31,   14,   55,   78,    8,   38,    1,
               7,    7,   31,   39,   31,   39,   47,   39,   31,   55,
              39,   23,   39,   55,   55,   47,   31,    7,    0,    7,
              31,   39,   31,   39,   47,   39,   31,   55,   39,   23,
              39,   55,   55,   47,   31,    7,    0,    7,   32,   23,
               0,    1,   17,    1,    7,   14,    7,    0,    0,   31,
              14,   54,   30,   23,   40,   14,    1,   54,   30,   23,
              40,   14,    1,   54,   30,   23,   40,   14,    1,    9,
              14,    0,    0,    8,   32,    8,   32,   38,   46,   30,
              23,   46,   30,   23,    1,   70,   70,   38,    1,   30,
              38,   46,   46,   72,   78,   40,   14,   32,   40,   24,
               6,  102,   54,   38,    1,   38,   24,   46,    8,   38,
              16,   16,    8,   38,
        },

        {
            /* Context Tables for init_idc = 1, qp = 14 */

              14,    1,   10,    7,   47,    1,   52,    1,   11,    1,
               1,   78,    1,    7,    1,    1,    1,   30,   37,   16,
              45,   37,   27,   11,   11,   14,   14,   23,   36,   22,
              37,   15,    8,   29,   14,   53,   78,   10,   38,    1,
               7,    7,   31,   37,   29,   37,   45,   37,   31,   53,
              37,   21,   37,   53,   53,   45,   29,    5,    0,    5,
              31,   37,   29,   37,   45,   37,   31,   53,   37,   21,
              37,   53,   53,   45,   29,    5,    0,    5,   32,   23,
               4,    1,   17,    1,    7,   14,    7,    0,    0,   27,
              14,   54,   30,   23,   40,   14,    1,   54,   30,   23,
              40,   14,    1,   54,   30,   23,   40,   14,    1,    9,
              14,    0,    0,   10,   32,   10,   32,   38,   46,   30,
              23,   46,   30,   23,    1,   68,   68,   38,    1,   30,
              38,   46,   46,   72,   78,   40,   14,   32,   40,   24,
               6,  100,   54,   38,    1,   38,   24,   46,   10,   38,
              18,   16,   10,   38,
        },

        {
            /* Context Tables for init_idc = 1, qp = 15 */

              14,    3,   12,    7,   45,    1,   50,    3,   13,    1,
               1,   78,    1,    7,    1,    1,    1,   30,   35,   18,
              43,   33,   23,    5,    5,   14,   14,   23,   34,   22,
              33,   13,    8,   27,   14,   51,   78,   12,   38,    1,
               7,    7,   29,   35,   27,   35,   43,   33,   29,   51,
              35,   17,   35,   51,   51,   43,   27,    3,    2,    3,
              29,   35,   27,   35,   43,   33,   29,   51,   35,   17,
              35,   51,   51,   43,   27,    3,    2,    3,   34,   23,
               8,    1,   17,    1,    7,   14,    7,    2,    2,   23,
              14,   54,   28,   23,   40,   14,    1,   54,   28,   23,
              40,   14,    1,   54,   28,   23,   40,   14,    1,    9,
              14,    2,    2,   12,   34,   12,   34,   38,   46,   28,
              23,   46,   28,   23,    1,   66,   66,   38,    1,   30,
              38,   44,   44,   72,   78,   40,   14,   34,   40,   24,
               6,   98,   54,   38,    1,   38,   24,   44,   12,   38,
              20,   18,   12,   38,
        },

        {
            /* Context Tables for init_idc = 1, qp = 16 */

              14,    5,   12,    7,   45,    1,   48,    5,   15,    1,
               1,   78,    1,    7,    1,    1,    1,   30,   35,   18,
              41,   31,   21,    1,    1,   14,   14,   23,   32,   20,
              31,   13,    8,   25,   14,   51,   78,   12,   36,    1,
               7,    7,   29,   35,   25,   35,   41,   31,   29,   51,
              35,   15,   35,   51,   51,   41,   25,    3,    2,    3,
              29,   35,   25,   35,   41,   31,   29,   51,   35,   15,
              35,   51,   51,   41,   25,    3,    2,    3,   34,   23,
              10,    1,   17,    1,    7,   14,    7,    2,    2,   21,
              14,   52,   26,   23,   40,   14,    1,   52,   26,   23,
              40,   14,    1,   52,   26,   23,   40,   14,    1,   11,
              14,    2,    2,   12,   34,   12,   34,   36,   46,   26,
              23,   46,   26,   23,    1,   64,   64,   36,    1,   30,
              36,   42,   42,   72,   78,   40,   14,   34,   40,   24,
               4,   96,   52,   36,    1,   36,   24,   42,   12,   36,
              22,   18,   12,   36,
        },

        {
            /* Context Tables for init_idc = 1, qp = 17 */

              14,    5,   14,    5,   43,    1,   48,    5,   15,    1,
               1,   78,    1,    5,    1,    1,    1,   30,   33,   20,
              37,   27,   17,    4,    4,   14,   14,   21,   32,   20,
              27,   11,   10,   21,   14,   49,   78,   14,   36,    1,
               5,    5,   27,   33,   21,   33,   37,   27,   27,   49,
              33,   11,   33,   49,   49,   37,   21,    1,    4,    1,
              27,   33,   21,   33,   37,   27,   27,   49,   33,   11,
              33,   49,   49,   37,   21,    1,    4,    1,   36,   21,
              14,    1,   17,    1,    5,   14,    5,    4,    4,   17,
              14,   52,   26,   21,   42,   14,    1,   52,   26,   21,
              42,   14,    1,   52,   26,   21,   42,   14,    1,   11,
              14,    4,    4,   14,   36,   14,   36,   36,   46,   26,
              21,   46,   26,   21,    1,   64,   64,   36,    1,   30,
              36,   42,   42,   74,   78,   42,   14,   36,   42,   26,
               4,   96,   52,   36,    1,   36,   26,   42,   14,   36,
              26,   20,   14,   36,
        },

        {
            /* Context Tables for init_idc = 1, qp = 18 */

              14,    7,   16,    5,   41,    1,   46,    7,   17,    1,
               1,   78,    1,    5,    1,    1,    1,   30,   31,   22,
              35,   23,   13,    8,    8,   14,   14,   21,   30,   20,
              23,    9,   10,   19,   14,   47,   78,   16,   36,    1,
               5,    5,   25,   31,   19,   31,   35,   23,   25,   47,
              31,    7,   31,   47,   47,   35,   19,    0,    6,    0,
              25,   31,   19,   31,   35,   23,   25,   47,   31,    7,
              31,   47,   47,   35,   19,    0,    6,    0,   38,   21,
              18,    1,   17,    1,    5,   14,    5,    6,    6,   13,
              14,   52,   24,   21,   42,   14,    1,   52,   24,   21,
              42,   14,    1,   52,   24,   21,   42,   14,    1,   11,
              14,    6,    6,   16,   38,   16,   38,   36,   46,   24,
              21,   46,   24,   21,    1,   62,   62,   36,    1,   30,
              36,   40,   40,   74,   78,   42,   14,   38,   42,   26,
               4,   94,   52,   36,    1,   36,   26,   40,   16,   36,
              28,   22,   16,   36,
        },

        {
            /* Context Tables for init_idc = 1, qp = 19 */

              14,    7,   18,    5,   41,    1,   44,    7,   19,    1,
               1,   78,    1,    5,    1,    1,    1,   30,   29,   22,
              33,   21,    9,   14,   14,   14,   14,   21,   28,   20,
              21,    9,   10,   17,   14,   45,   78,   18,   36,    1,
               5,    5,   25,   29,   17,   29,   33,   21,   25,   45,
              29,    5,   29,   45,   45,   33,   17,    2,    6,    2,
              25,   29,   17,   29,   33,   21,   25,   45,   29,    5,
              29,   45,   45,   33,   17,    2,    6,    2,   38,   21,
              22,    1,   17,    1,    5,   14,    5,    6,    6,    9,
              14,   52,   24,   21,   42,   14,    1,   52,   24,   21,
              42,   14,    1,   52,   24,   21,   42,   14,    1,   11,
              14,    6,    6,   18,   38,   18,   38,   36,   46,   24,
              21,   46,   24,   21,    1,   60,   60,   36,    1,   30,
              36,   40,   40,   74,   78,   42,   14,   38,   42,   26,
               4,   92,   52,   36,    1,   36,   26,   40,   18,   36,
              30,   22,   18,   36,
        },

        {
            /* Context Tables for init_idc = 1, qp = 20 */

              14,    9,   20,    3,   39,    1,   42,    9,   21,    1,
               1,   78,    1,    3,    1,    1,    1,   30,   27,   24,
              31,   17,    5,   18,   18,   14,   14,   19,   26,   18,
              17,    7,   12,   15,   14,   43,   78,   20,   34,    1,
               3,    3,   23,   27,   15,   27,   31,   17,   23,   43,
              27,    1,   27,   43,   43,   31,   15,    4,    8,    4,
              23,   27,   15,   27,   31,   17,   23,   43,   27,    1,
              27,   43,   43,   31,   15,    4,    8,    4,   40,   19,
              26,    1,   17,    1,    3,   14,    3,    8,    8,    5,
              14,   50,   22,   19,   44,   14,    1,   50,   22,   19,
              44,   14,    1,   50,   22,   19,   44,   14,    1,   13,
              14,    8,    8,   20,   40,   20,   40,   34,   46,   22,
              19,   46,   22,   19,    1,   58,   58,   34,    1,   30,
              34,   38,   38,   76,   78,   44,   14,   40,   44,   28,
               2,   90,   50,   34,    1,   34,   28,   38,   20,   34,
              32,   24,   20,   34,
        },

        {
            /* Context Tables for init_idc = 1, qp = 21 */

              14,   11,   22,    3,   37,    1,   40,   11,   23,    1,
               1,   78,    1,    3,    1,    1,    1,   30,   25,   26,
              27,   15,    1,   24,   24,   14,   14,   19,   24,   18,
              15,    5,   12,   11,   14,   41,   78,   22,   34,    1,
               3,    3,   21,   25,   11,   25,   27,   15,   21,   41,
              25,    0,   25,   41,   41,   27,   11,    6,   10,    6,
              21,   25,   11,   25,   27,   15,   21,   41,   25,    0,
              25,   41,   41,   27,   11,    6,   10,    6,   42,   19,
              30,    1,   17,    1,    3,   14,    3,   10,   10,    1,
              14,   50,   20,   19,   44,   14,    1,   50,   20,   19,
              44,   14,    1,   50,   20,   19,   44,   14,    1,   13,
              14,   10,   10,   22,   42,   22,   42,   34,   46,   20,
              19,   46,   20,   19,    1,   56,   56,   34,    1,   30,
              34,   36,   36,   76,   78,   44,   14,   42,   44,   28,
               2,   88,   50,   34,    1,   34,   28,   36,   22,   34,
              36,   26,   22,   34,
        },

        {
            /* Context Tables for init_idc = 1, qp = 22 */

              14,   11,   24,    3,   37,    1,   38,   11,   25,    1,
               1,   78,    1,    3,    1,    1,    1,   30,   23,   26,
              25,   11,    2,   28,   28,   14,   14,   19,   22,   18,
              11,    5,   12,    9,   14,   39,   78,   24,   34,    1,
               3,    3,   21,   23,    9,   23,   25,   11,   21,   39,
              23,    4,   23,   39,   39,   25,    9,    8,   10,    8,
              21,   23,    9,   23,   25,   11,   21,   39,   23,    4,
              23,   39,   39,   25,    9,    8,   10,    8,   42,   19,
              34,    1,   17,    1,    3,   14,    3,   10,   10,    2,
              14,   50,   20,   19,   44,   14,    1,   50,   20,   19,
              44,   14,    1,   50,   20,   19,   44,   14,    1,   13,
              14,   10,   10,   24,   42,   24,   42,   34,   46,   20,
              19,   46,   20,   19,    1,   54,   54,   34,    1,   30,
              34,   36,   36,   76,   78,   44,   14,   42,   44,   28,
               2,   86,   50,   34,    1,   34,   28,   36,   24,   34,
              38,   26,   24,   34,
        },

        {
            /* Context Tables for init_idc = 1, qp = 23 */

              14,   13,   26,    1,   35,    1,   36,   13,   27,    1,
               1,   78,    1,    1,    1,    1,    1,   30,   21,   28,
              23,    9,    6,   34,   34,   14,   14,   17,   20,   16,
               9,    3,   14,    7,   14,   37,   78,   26,   32,    1,
               1,    1,   19,   21,    7,   21,   23,    9,   19,   37,
              21,    6,   21,   37,   37,   23,    7,   10,   12,   10,
              19,   21,    7,   21,   23,    9,   19,   37,   21,    6,
              21,   37,   37,   23,    7,   10,   12,   10,   44,   17,
              38,    1,   17,    1,    1,   14,    1,   12,   12,    6,
              14,   48,   18,   17,   46,   14,    1,   48,   18,   17,
              46,   14,    1,   48,   18,   17,   46,   14,    1,   15,
              14,   12,   12,   26,   44,   26,   44,   32,   46,   18,
              17,   46,   18,   17,    1,   52,   52,   32,    1,   30,
              32,   34,   34,   78,   78,   46,   14,   44,   46,   30,
               0,   84,   48,   32,    1,   32,   30,   34,   26,   32,
              40,   28,   26,   32,
        },

        {
            /* Context Tables for init_idc = 1, qp = 24 */

              14,   15,   28,    1,   35,    1,   34,   15,   29,    1,
               1,   78,    1,    1,    1,    1,    1,   30,   19,   28,
              21,    5,    8,   38,   38,   14,   14,   17,   18,   16,
               5,    3,   14,    5,   14,   35,   78,   28,   32,    1,
               1,    1,   19,   19,    5,   19,   21,    5,   19,   35,
              19,   10,   19,   35,   35,   21,    5,   12,   12,   12,
              19,   19,    5,   19,   21,    5,   19,   35,   19,   10,
              19,   35,   35,   21,    5,   12,   12,   12,   44,   17,
              40,    1,   17,    1,    1,   14,    1,   12,   12,    8,
              14,   48,   16,   17,   46,   14,    1,   48,   16,   17,
              46,   14,    1,   48,   16,   17,   46,   14,    1,   15,
              14,   12,   12,   28,   44,   28,   44,   32,   46,   16,
              17,   46,   16,   17,    1,   50,   50,   32,    1,   30,
              32,   32,   32,   78,   78,   46,   14,   44,   46,   30,
               0,   82,   48,   32,    1,   32,   30,   32,   28,   32,
              42,   28,   28,   32,
        },

        {
            /* Context Tables for init_idc = 1, qp = 25 */

              14,   15,   30,    1,   33,    1,   32,   15,   31,    1,
               1,   78,    1,    1,    1,    1,    1,   30,   17,   30,
              17,    1,   12,   44,   44,   14,   14,   17,   16,   16,
               1,    1,   14,    1,   14,   33,   78,   30,   32,    1,
               1,    1,   17,   17,    1,   17,   17,    1,   17,   33,
              17,   14,   17,   33,   33,   17,    1,   14,   14,   14,
              17,   17,    1,   17,   17,    1,   17,   33,   17,   14,
              17,   33,   33,   17,    1,   14,   14,   14,   46,   17,
              44,    1,   17,    1,    1,   14,    1,   14,   14,   12,
              14,   48,   16,   17,   46,   14,    1,   48,   16,   17,
              46,   14,    1,   48,   16,   17,   46,   14,    1,   15,
              14,   14,   14,   30,   46,   30,   46,   32,   46,   16,
              17,   46,   16,   17,    1,   48,   48,   32,    1,   30,
              32,   32,   32,   78,   78,   46,   14,   46,   46,   30,
               0,   80,   48,   32,    1,   32,   30,   32,   30,   32,
              46,   30,   30,   32,
        },

        {
            /* Context Tables for init_idc = 1, qp = 26 */

              14,   17,   32,    0,   31,    1,   30,   17,   33,    1,
               1,   78,    1,    0,    1,    1,    1,   30,   15,   32,
              15,    0,   16,   48,   48,   14,   14,   15,   14,   14,
               0,    0,   16,    0,   14,   31,   78,   32,   30,    1,
               0,    0,   15,   15,    0,   15,   15,    0,   15,   31,
              15,   16,   15,   31,   31,   15,    0,   16,   16,   16,
              15,   15,    0,   15,   15,    0,   15,   31,   15,   16,
              15,   31,   31,   15,    0,   16,   16,   16,   48,   15,
              48,    1,   17,    1,    0,   14,    0,   16,   16,   16,
              14,   46,   14,   15,   48,   14,    1,   46,   14,   15,
              48,   14,    1,   46,   14,   15,   48,   14,    1,   17,
              14,   16,   16,   32,   48,   32,   48,   30,   46,   14,
              15,   46,   14,   15,    1,   46,   46,   30,    1,   30,
              30,   30,   30,   80,   78,   48,   14,   48,   48,   32,
               1,   78,   46,   30,    1,   30,   32,   30,   32,   30,
              48,   32,   32,   30,
        },

        {
            /* Context Tables for init_idc = 1, qp = 27 */

              14,   17,   34,    0,   31,    1,   28,   17,   35,    1,
               1,   78,    1,    0,    1,    1,    1,   30,   13,   32,
              13,    4,   20,   54,   54,   14,   14,   15,   12,   14,
               4,    0,   16,    2,   14,   29,   78,   34,   30,    1,
               0,    0,   15,   13,    2,   13,   13,    4,   15,   29,
              13,   20,   13,   29,   29,   13,    2,   18,   16,   18,
              15,   13,    2,   13,   13,    4,   15,   29,   13,   20,
              13,   29,   29,   13,    2,   18,   16,   18,   48,   15,
              52,    1,   17,    1,    0,   14,    0,   16,   16,   20,
              14,   46,   14,   15,   48,   14,    1,   46,   14,   15,
              48,   14,    1,   46,   14,   15,   48,   14,    1,   17,
              14,   16,   16,   34,   48,   34,   48,   30,   46,   14,
              15,   46,   14,   15,    1,   44,   44,   30,    1,   30,
              30,   30,   30,   80,   78,   48,   14,   48,   48,   32,
               1,   76,   46,   30,    1,   30,   32,   30,   34,   30,
              50,   32,   34,   30,
        },

        {
            /* Context Tables for init_idc = 1, qp = 28 */

              14,   19,   36,    0,   29,    1,   26,   19,   37,    1,
               1,   78,    1,    0,    1,    1,    1,   30,   11,   34,
              11,    6,   24,   58,   58,   14,   14,   15,   10,   14,
               6,    2,   16,    4,   14,   27,   78,   36,   30,    1,
               0,    0,   13,   11,    4,   11,   11,    6,   13,   27,
              11,   22,   11,   27,   27,   11,    4,   20,   18,   20,
              13,   11,    4,   11,   11,    6,   13,   27,   11,   22,
              11,   27,   27,   11,    4,   20,   18,   20,   50,   15,
              56,    1,   17,    1,    0,   14,    0,   18,   18,   24,
              14,   46,   12,   15,   48,   14,    1,   46,   12,   15,
              48,   14,    1,   46,   12,   15,   48,   14,    1,   17,
              14,   18,   18,   36,   50,   36,   50,   30,   46,   12,
              15,   46,   12,   15,    1,   42,   42,   30,    1,   30,
              30,   28,   28,   80,   78,   48,   14,   50,   48,   32,
               1,   74,   46,   30,    1,   30,   32,   28,   36,   30,
              52,   34,   36,   30,
        },

        {
            /* Context Tables for init_idc = 1, qp = 29 */

              14,   21,   38,    2,   27,    1,   24,   21,   39,    1,
               1,   78,    1,    2,    1,    1,    1,   30,    9,   36,
               7,   10,   28,   64,   64,   14,   14,   13,    8,   12,
              10,    4,   18,    8,   14,   25,   78,   38,   28,    1,
               2,    2,   11,    9,    8,    9,    7,   10,   11,   25,
               9,   26,    9,   25,   25,    7,    8,   22,   20,   22,
              11,    9,    8,    9,    7,   10,   11,   25,    9,   26,
               9,   25,   25,    7,    8,   22,   20,   22,   52,   13,
              60,    1,   17,    1,    2,   14,    2,   20,   20,   28,
              14,   44,   10,   13,   50,   14,    1,   44,   10,   13,
              50,   14,    1,   44,   10,   13,   50,   14,    1,   19,
              14,   20,   20,   38,   52,   38,   52,   28,   46,   10,
              13,   46,   10,   13,    1,   40,   40,   28,    1,   30,
              28,   26,   26,   82,   78,   50,   14,   52,   50,   34,
               3,   72,   44,   28,    1,   28,   34,   26,   38,   28,
              56,   36,   38,   28,
        },

        {
            /* Context Tables for init_idc = 1, qp = 30 */

              14,   21,   40,    2,   27,    1,   22,   21,   41,    1,
               1,   78,    1,    2,    1,    1,    1,   30,    7,   36,
               5,   12,   32,   68,   68,   14,   14,   13,    6,   12,
              12,    4,   18,   10,   14,   23,   78,   40,   28,    1,
               2,    2,   11,    7,   10,    7,    5,   12,   11,   23,
               7,   28,    7,   23,   23,    5,   10,   24,   20,   24,
              11,    7,   10,    7,    5,   12,   11,   23,    7,   28,
               7,   23,   23,    5,   10,   24,   20,   24,   52,   13,
              64,    1,   17,    1,    2,   14,    2,   20,   20,   32,
              14,   44,   10,   13,   50,   14,    1,   44,   10,   13,
              50,   14,    1,   44,   10,   13,   50,   14,    1,   19,
              14,   20,   20,   40,   52,   40,   52,   28,   46,   10,
              13,   46,   10,   13,    1,   38,   38,   28,    1,   30,
              28,   26,   26,   82,   78,   50,   14,   52,   50,   34,
               3,   70,   44,   28,    1,   28,   34,   26,   40,   28,
              58,   36,   40,   28,
        },

        {
            /* Context Tables for init_idc = 1, qp = 31 */

              14,   23,   42,    2,   25,    1,   20,   23,   43,    1,
               1,   78,    1,    2,    1,    1,    1,   30,    5,   38,
               3,   16,   36,   74,   74,   14,   14,   13,    4,   12,
              16,    6,   18,   12,   14,   21,   78,   42,   28,    1,
               2,    2,    9,    5,   12,    5,    3,   16,    9,   21,
               5,   32,    5,   21,   21,    3,   12,   26,   22,   26,
               9,    5,   12,    5,    3,   16,    9,   21,    5,   32,
               5,   21,   21,    3,   12,   26,   22,   26,   54,   13,
              68,    1,   17,    1,    2,   14,    2,   22,   22,   36,
              14,   44,    8,   13,   50,   14,    1,   44,    8,   13,
              50,   14,    1,   44,    8,   13,   50,   14,    1,   19,
              14,   22,   22,   42,   54,   42,   54,   28,   46,    8,
              13,   46,    8,   13,    1,   36,   36,   28,    1,   30,
              28,   24,   24,   82,   78,   50,   14,   54,   50,   34,
               3,   68,   44,   28,    1,   28,   34,   24,   42,   28,
              60,   38,   42,   28,
        },

        {
            /* Context Tables for init_idc = 1, qp = 32 */

              14,   25,   42,    2,   25,    1,   18,   25,   45,    1,
               1,   78,    1,    2,    1,    1,    1,   30,    5,   38,
               1,   18,   38,   78,   78,   14,   14,   13,    2,   10,
              18,    6,   18,   14,   14,   21,   78,   42,   26,    1,
               2,    2,    9,    5,   14,    5,    1,   18,    9,   21,
               5,   34,    5,   21,   21,    1,   14,   26,   22,   26,
               9,    5,   14,    5,    1,   18,    9,   21,    5,   34,
               5,   21,   21,    1,   14,   26,   22,   26,   54,   13,
              70,    1,   17,    1,    2,   14,    2,   22,   22,   38,
              14,   42,    6,   13,   50,   14,    1,   42,    6,   13,
              50,   14,    1,   42,    6,   13,   50,   14,    1,   21,
              14,   22,   22,   42,   54,   42,   54,   26,   46,    6,
              13,   46,    6,   13,    1,   34,   34,   26,    1,   30,
              26,   22,   22,   82,   78,   50,   14,   54,   50,   34,
               5,   66,   42,   26,    1,   26,   34,   22,   42,   26,
              62,   38,   42,   26,
        },

        {
            /* Context Tables for init_idc = 1, qp = 33 */

              14,   25,   44,    4,   23,    1,   18,   25,   45,    1,
               1,   78,    1,    4,    1,    1,    1,   30,    3,   40,
               2,   22,   42,   84,   84,   14,   14,   11,    2,   10,
              22,    8,   20,   18,   14,   19,   78,   44,   26,    1,
               4,    4,    7,    3,   18,    3,    2,   22,    7,   19,
               3,   38,    3,   19,   19,    2,   18,   28,   24,   28,
               7,    3,   18,    3,    2,   22,    7,   19,    3,   38,
               3,   19,   19,    2,   18,   28,   24,   28,   56,   11,
              74,    1,   17,    1,    4,   14,    4,   24,   24,   42,
              14,   42,    6,   11,   52,   14,    1,   42,    6,   11,
              52,   14,    1,   42,    6,   11,   52,   14,    1,   21,
              14,   24,   24,   44,   56,   44,   56,   26,   46,    6,
              11,   46,    6,   11,    1,   34,   34,   26,    1,   30,
              26,   22,   22,   84,   78,   52,   14,   56,   52,   36,
               5,   66,   42,   26,    1,   26,   36,   22,   44,   26,
              66,   40,   44,   26,
        },

        {
            /* Context Tables for init_idc = 1, qp = 34 */

              14,   27,   46,    4,   21,    1,   16,   27,   47,    1,
               1,   78,    1,    4,    1,    1,    1,   30,    1,   42,
               4,   26,   46,   88,   88,   14,   14,   11,    0,   10,
              26,   10,   20,   20,   14,   17,   78,   46,   26,    1,
               4,    4,    5,    1,   20,    1,    4,   26,    5,   17,
               1,   42,    1,   17,   17,    4,   20,   30,   26,   30,
               5,    1,   20,    1,    4,   26,    5,   17,    1,   42,
               1,   17,   17,    4,   20,   30,   26,   30,   58,   11,
              78,    1,   17,    1,    4,   14,    4,   26,   26,   46,
              14,   42,    4,   11,   52,   14,    1,   42,    4,   11,
              52,   14,    1,   42,    4,   11,   52,   14,    1,   21,
              14,   26,   26,   46,   58,   46,   58,   26,   46,    4,
              11,   46,    4,   11,    1,   32,   32,   26,    1,   30,
              26,   20,   20,   84,   78,   52,   14,   58,   52,   36,
               5,   64,   42,   26,    1,   26,   36,   20,   46,   26,
              68,   42,   46,   26,
        },

        {
            /* Context Tables for init_idc = 1, qp = 35 */

              14,   27,   48,    4,   21,    1,   14,   27,   49,    1,
               1,   78,    1,    4,    1,    1,    1,   30,    0,   42,
               6,   28,   50,   94,   94,   14,   14,   11,    1,   10,
              28,   10,   20,   22,   14,   15,   78,   48,   26,    1,
               4,    4,    5,    0,   22,    0,    6,   28,    5,   15,
               0,   44,    0,   15,   15,    6,   22,   32,   26,   32,
               5,    0,   22,    0,    6,   28,    5,   15,    0,   44,
               0,   15,   15,    6,   22,   32,   26,   32,   58,   11,
              82,    1,   17,    1,    4,   14,    4,   26,   26,   50,
              14,   42,    4,   11,   52,   14,    1,   42,    4,   11,
              52,   14,    1,   42,    4,   11,   52,   14,    1,   21,
              14,   26,   26,   48,   58,   48,   58,   26,   46,    4,
              11,   46,    4,   11,    1,   30,   30,   26,    1,   30,
              26,   20,   20,   84,   78,   52,   14,   58,   52,   36,
               5,   62,   42,   26,    1,   26,   36,   20,   48,   26,
              70,   42,   48,   26,
        },

        {
            /* Context Tables for init_idc = 1, qp = 36 */

              14,   29,   50,    6,   19,    1,   12,   29,   51,    1,
               1,   78,    1,    6,    1,    1,    1,   30,    2,   44,
               8,   32,   54,   98,   98,   14,   14,    9,    3,    8,
              32,   12,   22,   24,   14,   13,   78,   50,   24,    1,
               6,    6,    3,    2,   24,    2,    8,   32,    3,   13,
               2,   48,    2,   13,   13,    8,   24,   34,   28,   34,
               3,    2,   24,    2,    8,   32,    3,   13,    2,   48,
               2,   13,   13,    8,   24,   34,   28,   34,   60,    9,
              86,    1,   17,    1,    6,   14,    6,   28,   28,   54,
              14,   40,    2,    9,   54,   14,    1,   40,    2,    9,
              54,   14,    1,   40,    2,    9,   54,   14,    1,   23,
              14,   28,   28,   50,   60,   50,   60,   24,   46,    2,
               9,   46,    2,    9,    1,   28,   28,   24,    1,   30,
              24,   18,   18,   86,   78,   54,   14,   60,   54,   38,
               7,   60,   40,   24,    1,   24,   38,   18,   50,   24,
              72,   44,   50,   24,
        },

        {
            /* Context Tables for init_idc = 1, qp = 37 */

              14,   31,   52,    6,   17,    1,   10,   31,   53,    1,
               1,   78,    1,    6,    1,    1,    1,   30,    4,   46,
              12,   34,   58,  104,  104,   14,   14,    9,    5,    8,
              34,   14,   22,   28,   14,   11,   78,   52,   24,    1,
               6,    6,    1,    4,   28,    4,   12,   34,    1,   11,
               4,   50,    4,   11,   11,   12,   28,   36,   30,   36,
               1,    4,   28,    4,   12,   34,    1,   11,    4,   50,
               4,   11,   11,   12,   28,   36,   30,   36,   62,    9,
              90,    1,   17,    1,    6,   14,    6,   30,   30,   58,
              14,   40,    0,    9,   54,   14,    1,   40,    0,    9,
              54,   14,    1,   40,    0,    9,   54,   14,    1,   23,
              14,   30,   30,   52,   62,   52,   62,   24,   46,    0,
               9,   46,    0,    9,    1,   26,   26,   24,    1,   30,
              24,   16,   16,   86,   78,   54,   14,   62,   54,   38,
               7,   58,   40,   24,    1,   24,   38,   16,   52,   24,
              76,   46,   52,   24,
        },

        {
            /* Context Tables for init_idc = 1, qp = 38 */

              14,   31,   54,    6,   17,    1,    8,   31,   55,    1,
               1,   78,    1,    6,    1,    1,    1,   30,    6,   46,
              14,   38,   62,  108,  108,   14,   14,    9,    7,    8,
              38,   14,   22,   30,   14,    9,   78,   54,   24,    1,
               6,    6,    1,    6,   30,    6,   14,   38,    1,    9,
               6,   54,    6,    9,    9,   14,   30,   38,   30,   38,
               1,    6,   30,    6,   14,   38,    1,    9,    6,   54,
               6,    9,    9,   14,   30,   38,   30,   38,   62,    9,
              94,    1,   17,    1,    6,   14,    6,   30,   30,   62,
              14,   40,    0,    9,   54,   14,    1,   40,    0,    9,
              54,   14,    1,   40,    0,    9,   54,   14,    1,   23,
              14,   30,   30,   54,   62,   54,   62,   24,   46,    0,
               9,   46,    0,    9,    1,   24,   24,   24,    1,   30,
              24,   16,   16,   86,   78,   54,   14,   62,   54,   38,
               7,   56,   40,   24,    1,   24,   38,   16,   54,   24,
              78,   46,   54,   24,
        },

        {
            /* Context Tables for init_idc = 1, qp = 39 */

              14,   33,   56,    8,   15,    1,    6,   33,   57,    1,
               1,   78,    1,    8,    1,    1,    1,   30,    8,   48,
              16,   40,   66,  114,  114,   14,   14,    7,    9,    6,
              40,   16,   24,   32,   14,    7,   78,   56,   22,    1,
               8,    8,    0,    8,   32,    8,   16,   40,    0,    7,
               8,   56,    8,    7,    7,   16,   32,   40,   32,   40,
               0,    8,   32,    8,   16,   40,    0,    7,    8,   56,
               8,    7,    7,   16,   32,   40,   32,   40,   64,    7,
              98,    1,   17,    1,    8,   14,    8,   32,   32,   66,
              14,   38,    1,    7,   56,   14,    1,   38,    1,    7,
              56,   14,    1,   38,    1,    7,   56,   14,    1,   25,
              14,   32,   32,   56,   64,   56,   64,   22,   46,    1,
               7,   46,    1,    7,    1,   22,   22,   22,    1,   30,
              22,   14,   14,   88,   78,   56,   14,   64,   56,   40,
               9,   54,   38,   22,    1,   22,   40,   14,   56,   22,
              80,   48,   56,   22,
        },

        {
            /* Context Tables for init_idc = 1, qp = 40 */

              14,   35,   58,    8,   15,    1,    4,   35,   59,    1,
               1,   78,    1,    8,    1,    1,    1,   30,   10,   48,
              18,   44,   68,  118,  118,   14,   14,    7,   11,    6,
              44,   16,   24,   34,   14,    5,   78,   58,   22,    1,
               8,    8,    0,   10,   34,   10,   18,   44,    0,    5,
              10,   60,   10,    5,    5,   18,   34,   42,   32,   42,
               0,   10,   34,   10,   18,   44,    0,    5,   10,   60,
              10,    5,    5,   18,   34,   42,   32,   42,   64,    7,
             100,    1,   17,    1,    8,   14,    8,   32,   32,   68,
              14,   38,    3,    7,   56,   14,    1,   38,    3,    7,
              56,   14,    1,   38,    3,    7,   56,   14,    1,   25,
              14,   32,   32,   58,   64,   58,   64,   22,   46,    3,
               7,   46,    3,    7,    1,   20,   20,   22,    1,   30,
              22,   12,   12,   88,   78,   56,   14,   64,   56,   40,
               9,   52,   38,   22,    1,   22,   40,   12,   58,   22,
              82,   48,   58,   22,
        },

        {
            /* Context Tables for init_idc = 1, qp = 41 */

              14,   35,   60,    8,   13,    1,    2,   35,   61,    1,
               1,   78,    1,    8,    1,    1,    1,   30,   12,   50,
              22,   48,   72,  124,  124,   14,   14,    7,   13,    6,
              48,   18,   24,   38,   14,    3,   78,   60,   22,    1,
               8,    8,    2,   12,   38,   12,   22,   48,    2,    3,
              12,   64,   12,    3,    3,   22,   38,   44,   34,   44,
               2,   12,   38,   12,   22,   48,    2,    3,   12,   64,
              12,    3,    3,   22,   38,   44,   34,   44,   66,    7,
             104,    1,   17,    1,    8,   14,    8,   34,   34,   72,
              14,   38,    3,    7,   56,   14,    1,   38,    3,    7,
              56,   14,    1,   38,    3,    7,   56,   14,    1,   25,
              14,   34,   34,   60,   66,   60,   66,   22,   46,    3,
               7,   46,    3,    7,    1,   18,   18,   22,    1,   30,
              22,   12,   12,   88,   78,   56,   14,   66,   56,   40,
               9,   50,   38,   22,    1,   22,   40,   12,   60,   22,
              86,   50,   60,   22,
        },

        {
            /* Context Tables for init_idc = 1, qp = 42 */

              14,   37,   62,   10,   11,    1,    0,   37,   63,    1,
               1,   78,    1,   10,    1,    1,    1,   30,   14,   52,
              24,   50,   76,  124,  124,   14,   14,    5,   15,    4,
              50,   20,   26,   40,   14,    1,   78,   62,   20,    1,
              10,   10,    4,   14,   40,   14,   24,   50,    4,    1,
              14,   66,   14,    1,    1,   24,   40,   46,   36,   46,
               4,   14,   40,   14,   24,   50,    4,    1,   14,   66,
              14,    1,    1,   24,   40,   46,   36,   46,   68,    5,
             108,    1,   17,    1,   10,   14,   10,   36,   36,   76,
              14,   36,    5,    5,   58,   14,    1,   36,    5,    5,
              58,   14,    1,   36,    5,    5,   58,   14,    1,   27,
              14,   36,   36,   62,   68,   62,   68,   20,   46,    5,
               5,   46,    5,    5,    1,   16,   16,   20,    1,   30,
              20,   10,   10,   90,   78,   58,   14,   68,   58,   42,
              11,   48,   36,   20,    1,   20,   42,   10,   62,   20,
              88,   52,   62,   20,
        },

        {
            /* Context Tables for init_idc = 1, qp = 43 */

              14,   37,   64,   10,   11,    1,    1,   37,   65,    1,
               1,   78,    1,   10,    1,    1,    1,   30,   16,   52,
              26,   54,   80,  124,  124,   14,   14,    5,   17,    4,
              54,   20,   26,   42,   14,    0,   78,   64,   20,    1,
              10,   10,    4,   16,   42,   16,   26,   54,    4,    0,
              16,   70,   16,    0,    0,   26,   42,   48,   36,   48,
               4,   16,   42,   16,   26,   54,    4,    0,   16,   70,
              16,    0,    0,   26,   42,   48,   36,   48,   68,    5,
             112,    1,   17,    1,   10,   14,   10,   36,   36,   80,
              14,   36,    5,    5,   58,   14,    1,   36,    5,    5,
              58,   14,    1,   36,    5,    5,   58,   14,    1,   27,
              14,   36,   36,   64,   68,   64,   68,   20,   46,    5,
               5,   46,    5,    5,    1,   14,   14,   20,    1,   30,
              20,   10,   10,   90,   78,   58,   14,   68,   58,   42,
              11,   46,   36,   20,    1,   20,   42,   10,   64,   20,
              90,   52,   64,   20,
        },

        {
            /* Context Tables for init_idc = 1, qp = 44 */

              14,   39,   66,   10,    9,    1,    3,   39,   67,    1,
               1,   78,    1,   10,    1,    1,    1,   30,   18,   54,
              28,   56,   84,  124,  124,   14,   14,    5,   19,    4,
              56,   22,   26,   44,   14,    2,   78,   66,   20,    1,
              10,   10,    6,   18,   44,   18,   28,   56,    6,    2,
              18,   72,   18,    2,    2,   28,   44,   50,   38,   50,
               6,   18,   44,   18,   28,   56,    6,    2,   18,   72,
              18,    2,    2,   28,   44,   50,   38,   50,   70,    5,
             116,    1,   17,    1,   10,   14,   10,   38,   38,   84,
              14,   36,    7,    5,   58,   14,    1,   36,    7,    5,
              58,   14,    1,   36,    7,    5,   58,   14,    1,   27,
              14,   38,   38,   66,   70,   66,   70,   20,   46,    7,
               5,   46,    7,    5,    1,   12,   12,   20,    1,   30,
              20,    8,    8,   90,   78,   58,   14,   70,   58,   42,
              11,   44,   36,   20,    1,   20,   42,    8,   66,   20,
              92,   54,   66,   20,
        },

        {
            /* Context Tables for init_idc = 1, qp = 45 */

              14,   41,   68,   12,    7,    1,    5,   41,   69,    1,
               1,   78,    1,   12,    1,    1,    1,   30,   20,   56,
              32,   60,   88,  124,  124,   14,   14,    3,   21,    2,
              60,   24,   28,   48,   14,    4,   78,   68,   18,    1,
              12,   12,    8,   20,   48,   20,   32,   60,    8,    4,
              20,   76,   20,    4,    4,   32,   48,   52,   40,   52,
               8,   20,   48,   20,   32,   60,    8,    4,   20,   76,
              20,    4,    4,   32,   48,   52,   40,   52,   72,    3,
             120,    1,   17,    1,   12,   14,   12,   40,   40,   88,
              14,   34,    9,    3,   60,   14,    1,   34,    9,    3,
              60,   14,    1,   34,    9,    3,   60,   14,    1,   29,
              14,   40,   40,   68,   72,   68,   72,   18,   46,    9,
               3,   46,    9,    3,    1,   10,   10,   18,    1,   30,
              18,    6,    6,   92,   78,   60,   14,   72,   60,   44,
              13,   42,   34,   18,    1,   18,   44,    6,   68,   18,
              96,   56,   68,   18,
        },

        {
            /* Context Tables for init_idc = 1, qp = 46 */

              14,   41,   70,   12,    7,    1,    7,   41,   71,    1,
               1,   78,    1,   12,    1,    1,    1,   30,   22,   56,
              34,   62,   92,  124,  124,   14,   14,    3,   23,    2,
              62,   24,   28,   50,   14,    6,   78,   70,   18,    1,
              12,   12,    8,   22,   50,   22,   34,   62,    8,    6,
              22,   78,   22,    6,    6,   34,   50,   54,   40,   54,
               8,   22,   50,   22,   34,   62,    8,    6,   22,   78,
              22,    6,    6,   34,   50,   54,   40,   54,   72,    3,
             124,    1,   17,    1,   12,   14,   12,   40,   40,   92,
              14,   34,    9,    3,   60,   14,    1,   34,    9,    3,
              60,   14,    1,   34,    9,    3,   60,   14,    1,   29,
              14,   40,   40,   70,   72,   70,   72,   18,   46,    9,
               3,   46,    9,    3,    1,    8,    8,   18,    1,   30,
              18,    6,    6,   92,   78,   60,   14,   72,   60,   44,
              13,   40,   34,   18,    1,   18,   44,    6,   70,   18,
              98,   56,   70,   18,
        },

        {
            /* Context Tables for init_idc = 1, qp = 47 */

              14,   43,   72,   12,    5,    1,    9,   43,   73,    1,
               1,   78,    1,   12,    1,    1,    1,   30,   24,   58,
              36,   66,   96,  124,  124,   14,   14,    3,   25,    2,
              66,   26,   28,   52,   14,    8,   78,   72,   18,    1,
              12,   12,   10,   24,   52,   24,   36,   66,   10,    8,
              24,   82,   24,    8,    8,   36,   52,   56,   42,   56,
              10,   24,   52,   24,   36,   66,   10,    8,   24,   82,
              24,    8,    8,   36,   52,   56,   42,   56,   74,    3,
             124,    1,   17,    1,   12,   14,   12,   42,   42,   96,
              14,   34,   11,    3,   60,   14,    1,   34,   11,    3,
              60,   14,    1,   34,   11,    3,   60,   14,    1,   29,
              14,   42,   42,   72,   74,   72,   74,   18,   46,   11,
               3,   46,   11,    3,    1,    6,    6,   18,    1,   30,
              18,    4,    4,   92,   78,   60,   14,   74,   60,   44,
              13,   38,   34,   18,    1,   18,   44,    4,   72,   18,
             100,   58,   72,   18,
        },

        {
            /* Context Tables for init_idc = 1, qp = 48 */

              14,   45,   72,   12,    5,    1,   11,   45,   75,    1,
               1,   78,    1,   12,    1,    1,    1,   30,   24,   58,
              38,   68,   98,  124,  124,   14,   14,    3,   27,    0,
              68,   26,   28,   54,   14,    8,   78,   72,   16,    1,
              12,   12,   10,   24,   54,   24,   38,   68,   10,    8,
              24,   84,   24,    8,    8,   38,   54,   56,   42,   56,
              10,   24,   54,   24,   38,   68,   10,    8,   24,   84,
              24,    8,    8,   38,   54,   56,   42,   56,   74,    3,
             124,    1,   17,    1,   12,   14,   12,   42,   42,   98,
              14,   32,   13,    3,   60,   14,    1,   32,   13,    3,
              60,   14,    1,   32,   13,    3,   60,   14,    1,   31,
              14,   42,   42,   72,   74,   72,   74,   16,   46,   13,
               3,   46,   13,    3,    1,    4,    4,   16,    1,   30,
              16,    2,    2,   92,   78,   60,   14,   74,   60,   44,
              15,   36,   32,   16,    1,   16,   44,    2,   72,   16,
             102,   58,   72,   16,
        },

        {
            /* Context Tables for init_idc = 1, qp = 49 */

              14,   45,   74,   14,    3,    1,   11,   45,   75,    1,
               1,   78,    1,   14,    1,    1,    1,   30,   26,   60,
              42,   72,  102,  124,  124,   14,   14,    1,   27,    0,
              72,   28,   30,   58,   14,   10,   78,   74,   16,    1,
              14,   14,   12,   26,   58,   26,   42,   72,   12,   10,
              26,   88,   26,   10,   10,   42,   58,   58,   44,   58,
              12,   26,   58,   26,   42,   72,   12,   10,   26,   88,
              26,   10,   10,   42,   58,   58,   44,   58,   76,    1,
             124,    1,   17,    1,   14,   14,   14,   44,   44,  102,
              14,   32,   13,    1,   62,   14,    1,   32,   13,    1,
              62,   14,    1,   32,   13,    1,   62,   14,    1,   31,
              14,   44,   44,   74,   76,   74,   76,   16,   46,   13,
               1,   46,   13,    1,    1,    4,    4,   16,    1,   30,
              16,    2,    2,   94,   78,   62,   14,   76,   62,   46,
              15,   36,   32,   16,    1,   16,   46,    2,   74,   16,
             106,   60,   74,   16,
        },

        {
            /* Context Tables for init_idc = 1, qp = 50 */

              14,   47,   76,   14,    1,    1,   13,   47,   77,    1,
               1,   78,    1,   14,    1,    1,    1,   30,   28,   62,
              44,   76,  106,  124,  124,   14,   14,    1,   29,    0,
              76,   30,   30,   60,   14,   12,   78,   76,   16,    1,
              14,   14,   14,   28,   60,   28,   44,   76,   14,   12,
              28,   92,   28,   12,   12,   44,   60,   60,   46,   60,
              14,   28,   60,   28,   44,   76,   14,   12,   28,   92,
              28,   12,   12,   44,   60,   60,   46,   60,   78,    1,
             124,    1,   17,    1,   14,   14,   14,   46,   46,  106,
              14,   32,   15,    1,   62,   14,    1,   32,   15,    1,
              62,   14,    1,   32,   15,    1,   62,   14,    1,   31,
              14,   46,   46,   76,   78,   76,   78,   16,   46,   15,
               1,   46,   15,    1,    1,    2,    2,   16,    1,   30,
              16,    0,    0,   94,   78,   62,   14,   78,   62,   46,
              15,   34,   32,   16,    1,   16,   46,    0,   76,   16,
             108,   62,   76,   16,
        },

        {
            /* Context Tables for init_idc = 1, qp = 51 */

              14,   47,   78,   14,    1,    1,   15,   47,   79,    1,
               1,   78,    1,   14,    1,    1,    1,   30,   30,   62,
              46,   78,  110,  124,  124,   14,   14,    1,   31,    0,
              78,   30,   30,   62,   14,   14,   78,   78,   16,    1,
              14,   14,   14,   30,   62,   30,   46,   78,   14,   14,
              30,   94,   30,   14,   14,   46,   62,   62,   46,   62,
              14,   30,   62,   30,   46,   78,   14,   14,   30,   94,
              30,   14,   14,   46,   62,   62,   46,   62,   78,    1,
             124,    1,   17,    1,   14,   14,   14,   46,   46,  110,
              14,   32,   15,    1,   62,   14,    1,   32,   15,    1,
              62,   14,    1,   32,   15,    1,   62,   14,    1,   31,
              14,   46,   46,   78,   78,   78,   78,   16,   46,   15,
               1,   46,   15,    1,    1,    0,    0,   16,    1,   30,
              16,    0,    0,   94,   78,   62,   14,   78,   62,   46,
              15,   32,   32,   16,    1,   16,   46,    0,   78,   16,
             110,   62,   78,   16,
        },

    },

    {
        {
            /* Context Tables for init_idc = 2, qp =  0 */

              14,  124,   17,   17,   65,    1,   78,   14,   14,    1,
               1,   62,    1,   17,    1,    1,   46,   30,    1,   14,
              81,   81,   81,   81,   81,   14,   14,   14,   62,   30,
              81,  124,   46,    1,   14,   81,   78,   33,   46,    1,
              17,   17,   49,   65,   33,   65,   81,   65,   49,   81,
              81,   81,   49,   65,   81,   81,   81,   33,   17,   49,
              49,   65,   33,   65,   81,   65,   49,   81,   81,   81,
              49,   65,   81,   81,   81,   33,   17,   49,   14,   33,
              49,    1,    1,    1,   17,   14,   17,   17,   17,   81,
              33,   62,   46,   33,   30,   14,    1,   62,   46,   33,
              30,   14,    1,   62,   46,   33,   30,   14,    1,    1,
              14,    1,    1,    1,   14,    1,   14,   46,   46,   46,
              33,   46,   46,   33,    1,   94,   46,   46,    1,   30,
              46,   62,   62,   62,   78,   30,   14,   14,   30,    1,
              14,  124,   62,   46,    1,   30,   46,   62,   17,   46,
              17,   17,   17,   46,
        },

        {
            /* Context Tables for init_idc = 2, qp =  1 */

              14,  124,   15,   15,   63,    1,   78,   14,   14,    1,
               1,   64,    1,   15,    1,    1,   46,   30,    1,   16,
              77,   77,   77,   75,   75,   14,   14,   14,   62,   30,
              77,  124,   46,    0,   14,   79,   78,   29,   46,    1,
              15,   15,   47,   63,   31,   63,   77,   61,   47,   79,
              79,   77,   47,   63,   79,   79,   77,   31,   15,   45,
              47,   63,   31,   63,   77,   61,   47,   79,   79,   77,
              47,   63,   79,   79,   77,   31,   15,   45,   16,   31,
              45,    1,    1,    1,   15,   14,   15,   15,   15,   77,
              31,   62,   46,   31,   32,   14,    1,   62,   46,   31,
              32,   14,    1,   62,   46,   31,   32,   14,    1,    1,
              14,    0,    0,    0,   16,    0,   16,   46,   46,   46,
              31,   46,   46,   31,    1,   94,   46,   46,    1,   30,
              46,   62,   62,   64,   78,   32,   14,   16,   32,    0,
              14,  124,   62,   46,    1,   30,   46,   62,   15,   46,
              13,   15,   15,   46,
        },

        {
            /* Context Tables for init_idc = 2, qp =  2 */

              14,  124,   13,   15,   61,    1,   76,   12,   12,    1,
               1,   64,    1,   15,    1,    1,   44,   30,    1,   16,
              75,   73,   73,   71,   71,   14,   14,   14,   60,   30,
              73,  124,   46,    2,   14,   77,   78,   27,   46,    1,
              15,   15,   45,   61,   29,   61,   75,   59,   45,   77,
              77,   73,   45,   61,   77,   77,   73,   29,   13,   43,
              45,   61,   29,   61,   75,   59,   45,   77,   77,   73,
              45,   61,   77,   77,   73,   29,   13,   43,   18,   31,
              41,    1,    1,    1,   15,   14,   15,   13,   13,   73,
              29,   62,   44,   31,   32,   14,    1,   62,   44,   31,
              32,   14,    1,   62,   44,   31,   32,   14,    1,    1,
              14,    0,    0,    2,   18,    2,   18,   46,   46,   44,
              31,   46,   44,   31,    1,   92,   46,   46,    1,   30,
              46,   60,   60,   64,   78,   32,   14,   18,   32,    2,
              14,  124,   62,   46,    1,   30,   46,   60,   13,   46,
              11,   13,   13,   46,
        },

        {
            /* Context Tables for init_idc = 2, qp =  3 */

              14,  124,   11,   15,   61,    1,   74,   12,   10,    1,
               1,   64,    1,   15,    1,    1,   44,   30,    1,   16,
              73,   71,   69,   65,   65,   14,   14,   14,   58,   30,
              71,  124,   46,    2,   14,   75,   78,   25,   46,    1,
              15,   15,   45,   59,   29,   59,   73,   57,   45,   75,
              75,   71,   45,   61,   75,   75,   71,   27,   13,   41,
              45,   59,   29,   59,   73,   57,   45,   75,   75,   71,
              45,   61,   75,   75,   71,   27,   13,   41,   18,   31,
              37,    1,    1,    1,   15,   14,   15,   13,   13,   69,
              29,   62,   44,   31,   32,   14,    1,   62,   44,   31,
              32,   14,    1,   62,   44,   31,   32,   14,    1,    1,
              14,    0,    0,    2,   18,    2,   18,   46,   46,   44,
              31,   46,   44,   31,    1,   90,   46,   46,    1,   30,
              46,   60,   60,   64,   78,   32,   14,   18,   32,    2,
              14,  124,   62,   46,    1,   30,   46,   60,   11,   46,
               9,   11,   11,   46,
        },

        {
            /* Context Tables for init_idc = 2, qp =  4 */

              14,  124,    9,   13,   59,    1,   72,   10,    8,    1,
               1,   66,    1,   13,    1,    1,   42,   30,    1,   18,
              71,   67,   65,   61,   61,   14,   14,   12,   56,   28,
              67,  124,   44,    4,   14,   73,   78,   23,   44,    1,
              13,   13,   43,   57,   27,   57,   71,   55,   43,   73,
              73,   67,   43,   59,   73,   73,   67,   25,   11,   39,
              43,   57,   27,   57,   71,   55,   43,   73,   73,   67,
              43,   59,   73,   73,   67,   25,   11,   39,   20,   29,
              33,    1,    3,    1,   13,   14,   13,   11,   11,   65,
              27,   60,   42,   29,   34,   14,    1,   60,   42,   29,
              34,   14,    1,   60,   42,   29,   34,   14,    1,    3,
              14,    2,    2,    4,   20,    4,   20,   44,   46,   42,
              29,   46,   42,   29,    1,   88,   44,   44,    1,   30,
              44,   58,   58,   66,   78,   34,   14,   20,   34,    4,
              12,  124,   60,   44,    1,   30,   44,   58,    9,   44,
               7,    9,    9,   44,
        },

        {
            /* Context Tables for init_idc = 2, qp =  5 */

              14,  124,    7,   13,   57,    1,   70,    8,    6,    1,
               1,   66,    1,   13,    1,    1,   40,   30,    1,   18,
              67,   65,   61,   55,   55,   14,   14,   12,   54,   28,
              65,  124,   44,    6,   14,   71,   78,   19,   44,    1,
              13,   13,   41,   55,   25,   55,   67,   51,   41,   71,
              71,   65,   41,   57,   71,   71,   65,   23,    9,   35,
              41,   55,   25,   55,   67,   51,   41,   71,   71,   65,
              41,   57,   71,   71,   65,   23,    9,   35,   22,   29,
              29,    1,    3,    1,   13,   14,   13,    9,    9,   61,
              25,   60,   40,   29,   34,   14,    1,   60,   40,   29,
              34,   14,    1,   60,   40,   29,   34,   14,    1,    3,
              14,    2,    2,    6,   22,    6,   22,   44,   46,   40,
              29,   46,   40,   29,    1,   86,   44,   44,    1,   30,
              44,   56,   56,   66,   78,   34,   14,   22,   34,    6,
              12,  124,   60,   44,    1,   30,   44,   56,    7,   44,
               3,    7,    7,   44,
        },

        {
            /* Context Tables for init_idc = 2, qp =  6 */

              14,  124,    5,   13,   57,    1,   68,    8,    4,    1,
               1,   66,    1,   13,    1,    1,   40,   30,    1,   18,
              65,   61,   57,   51,   51,   14,   14,   12,   52,   28,
              61,  124,   44,    6,   14,   69,   78,   17,   44,    1,
              13,   13,   41,   53,   25,   53,   65,   49,   41,   69,
              69,   61,   41,   57,   69,   69,   61,   21,    9,   33,
              41,   53,   25,   53,   65,   49,   41,   69,   69,   61,
              41,   57,   69,   69,   61,   21,    9,   33,   22,   29,
              25,    1,    3,    1,   13,   14,   13,    9,    9,   57,
              25,   60,   40,   29,   34,   14,    1,   60,   40,   29,
              34,   14,    1,   60,   40,   29,   34,   14,    1,    3,
              14,    2,    2,    6,   22,    6,   22,   44,   46,   40,
              29,   46,   40,   29,    1,   84,   44,   44,    1,   30,
              44,   56,   56,   66,   78,   34,   14,   22,   34,    6,
              12,  124,   60,   44,    1,   30,   44,   56,    5,   44,
               1,    5,    5,   44,
        },

        {
            /* Context Tables for init_idc = 2, qp =  7 */

              14,  124,    3,   11,   55,    1,   66,    6,    2,    1,
               1,   68,    1,   11,    1,    1,   38,   30,    1,   20,
              63,   59,   53,   45,   45,   14,   14,   10,   50,   26,
              59,  124,   42,    8,   14,   67,   78,   15,   42,    1,
              11,   11,   39,   51,   23,   51,   63,   47,   39,   67,
              67,   59,   39,   55,   67,   67,   59,   19,    7,   31,
              39,   51,   23,   51,   63,   47,   39,   67,   67,   59,
              39,   55,   67,   67,   59,   19,    7,   31,   24,   27,
              21,    1,    5,    1,   11,   14,   11,    7,    7,   53,
              23,   58,   38,   27,   36,   14,    1,   58,   38,   27,
              36,   14,    1,   58,   38,   27,   36,   14,    1,    5,
              14,    4,    4,    8,   24,    8,   24,   42,   46,   38,
              27,   46,   38,   27,    1,   82,   42,   42,    1,   30,
              42,   54,   54,   68,   78,   36,   14,   24,   36,    8,
              10,  124,   58,   42,    1,   30,   42,   54,    3,   42,
               0,    3,    3,   42,
        },

        {
            /* Context Tables for init_idc = 2, qp =  8 */

              14,  124,    1,   11,   55,    1,   64,    4,    0,    1,
               1,   68,    1,   11,    1,    1,   36,   30,    1,   20,
              61,   55,   51,   41,   41,   14,   14,   10,   48,   26,
              55,  124,   42,    8,   14,   65,   78,   13,   42,    1,
              11,   11,   39,   49,   23,   49,   61,   45,   39,   65,
              65,   55,   39,   55,   65,   65,   55,   17,    7,   29,
              39,   49,   23,   49,   61,   45,   39,   65,   65,   55,
              39,   55,   65,   65,   55,   17,    7,   29,   24,   27,
              19,    1,    5,    1,   11,   14,   11,    7,    7,   51,
              23,   58,   36,   27,   36,   14,    1,   58,   36,   27,
              36,   14,    1,   58,   36,   27,   36,   14,    1,    5,
              14,    4,    4,    8,   24,    8,   24,   42,   46,   36,
              27,   46,   36,   27,    1,   80,   42,   42,    1,   30,
              42,   52,   52,   68,   78,   36,   14,   24,   36,    8,
              10,  124,   58,   42,    1,   30,   42,   52,    1,   42,
               2,    1,    1,   42,
        },

        {
            /* Context Tables for init_idc = 2, qp =  9 */

              14,  124,    0,   11,   53,    1,   62,    4,    1,    1,
               1,   68,    1,   11,    1,    1,   36,   30,    1,   20,
              57,   51,   47,   35,   35,   14,   14,   10,   46,   26,
              51,  124,   42,   10,   14,   63,   78,    9,   42,    1,
              11,   11,   37,   47,   21,   47,   57,   41,   37,   63,
              63,   51,   37,   53,   63,   63,   51,   15,    5,   25,
              37,   47,   21,   47,   57,   41,   37,   63,   63,   51,
              37,   53,   63,   63,   51,   15,    5,   25,   26,   27,
              15,    1,    5,    1,   11,   14,   11,    5,    5,   47,
              21,   58,   36,   27,   36,   14,    1,   58,   36,   27,
              36,   14,    1,   58,   36,   27,   36,   14,    1,    5,
              14,    4,    4,   10,   26,   10,   26,   42,   46,   36,
              27,   46,   36,   27,    1,   78,   42,   42,    1,   30,
              42,   52,   52,   68,   78,   36,   14,   26,   36,   10,
              10,  124,   58,   42,    1,   30,   42,   52,    0,   42,
               6,    0,    0,   42,
        },

        {
            /* Context Tables for init_idc = 2, qp = 10 */

              14,  124,    2,    9,   51,    1,   60,    2,    3,    1,
               1,   70,    1,    9,    1,    1,   34,   30,    1,   22,
              55,   49,   43,   31,   31,   14,   14,    8,   44,   24,
              49,  124,   40,   12,   14,   61,   78,    7,   40,    1,
               9,    9,   35,   45,   19,   45,   55,   39,   35,   61,
              61,   49,   35,   51,   61,   61,   49,   13,    3,   23,
              35,   45,   19,   45,   55,   39,   35,   61,   61,   49,
              35,   51,   61,   61,   49,   13,    3,   23,   28,   25,
              11,    1,    7,    1,    9,   14,    9,    3,    3,   43,
              19,   56,   34,   25,   38,   14,    1,   56,   34,   25,
              38,   14,    1,   56,   34,   25,   38,   14,    1,    7,
              14,    6,    6,   12,   28,   12,   28,   40,   46,   34,
              25,   46,   34,   25,    1,   76,   40,   40,    1,   30,
              40,   50,   50,   70,   78,   38,   14,   28,   38,   12,
               8,  124,   56,   40,    1,   30,   40,   50,    2,   40,
               8,    2,    2,   40,
        },

        {
            /* Context Tables for init_idc = 2, qp = 11 */

              14,  124,    4,    9,   51,    1,   58,    2,    5,    1,
               1,   70,    1,    9,    1,    1,   34,   30,    1,   22,
              53,   45,   39,   25,   25,   14,   14,    8,   42,   24,
              45,  124,   40,   12,   14,   59,   78,    5,   40,    1,
               9,    9,   35,   43,   19,   43,   53,   37,   35,   59,
              59,   45,   35,   51,   59,   59,   45,   11,    3,   21,
              35,   43,   19,   43,   53,   37,   35,   59,   59,   45,
              35,   51,   59,   59,   45,   11,    3,   21,   28,   25,
               7,    1,    7,    1,    9,   14,    9,    3,    3,   39,
              19,   56,   34,   25,   38,   14,    1,   56,   34,   25,
              38,   14,    1,   56,   34,   25,   38,   14,    1,    7,
              14,    6,    6,   12,   28,   12,   28,   40,   46,   34,
              25,   46,   34,   25,    1,   74,   40,   40,    1,   30,
              40,   50,   50,   70,   78,   38,   14,   28,   38,   12,
               8,  124,   56,   40,    1,   30,   40,   50,    4,   40,
              10,    4,    4,   40,
        },

        {
            /* Context Tables for init_idc = 2, qp = 12 */

              14,  124,    6,    9,   49,    1,   56,    0,    7,    1,
               1,   70,    1,    9,    1,    1,   32,   30,    1,   22,
              51,   43,   35,   21,   21,   14,   14,    8,   40,   24,
              43,  122,   40,   14,   14,   57,   78,    3,   40,    1,
               9,    9,   33,   41,   17,   41,   51,   35,   33,   57,
              57,   43,   33,   49,   57,   57,   43,    9,    1,   19,
              33,   41,   17,   41,   51,   35,   33,   57,   57,   43,
              33,   49,   57,   57,   43,    9,    1,   19,   30,   25,
               3,    1,    7,    1,    9,   14,    9,    1,    1,   35,
              17,   56,   32,   25,   38,   14,    1,   56,   32,   25,
              38,   14,    1,   56,   32,   25,   38,   14,    1,    7,
              14,    6,    6,   14,   30,   14,   30,   40,   46,   32,
              25,   46,   32,   25,    1,   72,   40,   40,    1,   30,
              40,   48,   48,   70,   78,   38,   14,   30,   38,   14,
               8,  124,   56,   40,    1,   30,   40,   48,    6,   40,
              12,    6,    6,   40,
        },

        {
            /* Context Tables for init_idc = 2, qp = 13 */

              14,  124,    8,    7,   47,    1,   54,    1,    9,    1,
               1,   72,    1,    7,    1,    1,   30,   30,    1,   24,
              47,   39,   31,   15,   15,   14,   14,    6,   38,   22,
              39,  118,   38,   16,   14,   55,   78,    0,   38,    1,
               7,    7,   31,   39,   15,   39,   47,   31,   31,   55,
              55,   39,   31,   47,   55,   55,   39,    7,    0,   15,
              31,   39,   15,   39,   47,   31,   31,   55,   55,   39,
              31,   47,   55,   55,   39,    7,    0,   15,   32,   23,
               0,    1,    9,    1,    7,   14,    7,    0,    0,   31,
              15,   54,   30,   23,   40,   14,    1,   54,   30,   23,
              40,   14,    1,   54,   30,   23,   40,   14,    1,    9,
              14,    8,    8,   16,   32,   16,   32,   38,   46,   30,
              23,   46,   30,   23,    1,   70,   38,   38,    1,   30,
              38,   46,   46,   72,   78,   40,   14,   32,   40,   16,
               6,  124,   54,   38,    1,   30,   38,   46,    8,   38,
              16,    8,    8,   38,
        },

        {
            /* Context Tables for init_idc = 2, qp = 14 */

              14,  124,   10,    7,   47,    1,   52,    1,   11,    1,
               1,   72,    1,    7,    1,    1,   30,   30,    1,   24,
              45,   37,   27,   11,   11,   14,   14,    6,   36,   22,
              37,  116,   38,   16,   14,   53,   78,    2,   38,    1,
               7,    7,   31,   37,   15,   37,   45,   29,   31,   53,
              53,   37,   31,   47,   53,   53,   37,    5,    0,   13,
              31,   37,   15,   37,   45,   29,   31,   53,   53,   37,
              31,   47,   53,   53,   37,    5,    0,   13,   32,   23,
               4,    1,    9,    1,    7,   14,    7,    0,    0,   27,
              15,   54,   30,   23,   40,   14,    1,   54,   30,   23,
              40,   14,    1,   54,   30,   23,   40,   14,    1,    9,
              14,    8,    8,   16,   32,   16,   32,   38,   46,   30,
              23,   46,   30,   23,    1,   68,   38,   38,    1,   30,
              38,   46,   46,   72,   78,   40,   14,   32,   40,   16,
               6,  124,   54,   38,    1,   30,   38,   46,   10,   38,
              18,   10,   10,   38,
        },

        {
            /* Context Tables for init_idc = 2, qp = 15 */

              14,  124,   12,    7,   45,    1,   50,    3,   13,    1,
               1,   72,    1,    7,    1,    1,   28,   30,    1,   24,
              43,   33,   23,    5,    5,   14,   14,    6,   34,   22,
              33,  112,   38,   18,   14,   51,   78,    4,   38,    1,
               7,    7,   29,   35,   13,   35,   43,   27,   29,   51,
              51,   33,   29,   45,   51,   51,   33,    3,    2,   11,
              29,   35,   13,   35,   43,   27,   29,   51,   51,   33,
              29,   45,   51,   51,   33,    3,    2,   11,   34,   23,
               8,    1,    9,    1,    7,   14,    7,    2,    2,   23,
              13,   54,   28,   23,   40,   14,    1,   54,   28,   23,
              40,   14,    1,   54,   28,   23,   40,   14,    1,    9,
              14,    8,    8,   18,   34,   18,   34,   38,   46,   28,
              23,   46,   28,   23,    1,   66,   38,   38,    1,   30,
              38,   44,   44,   72,   78,   40,   14,   34,   40,   18,
               6,  122,   54,   38,    1,   30,   38,   44,   12,   38,
              20,   12,   12,   38,
        },

        {
            /* Context Tables for init_idc = 2, qp = 16 */

              14,  124,   12,    7,   45,    1,   48,    5,   15,    1,
               1,   72,    1,    7,    1,    1,   26,   30,    1,   24,
              41,   31,   21,    1,    1,   14,   14,    4,   32,   20,
              31,  108,   36,   18,   14,   51,   78,    6,   36,    1,
               7,    7,   29,   35,   13,   35,   41,   25,   29,   51,
              51,   31,   29,   45,   51,   51,   31,    3,    2,    9,
              29,   35,   13,   35,   41,   25,   29,   51,   51,   31,
              29,   45,   51,   51,   31,    3,    2,    9,   34,   23,
              10,    1,   11,    1,    7,   14,    7,    2,    2,   21,
              13,   52,   26,   23,   40,   14,    1,   52,   26,   23,
              40,   14,    1,   52,   26,   23,   40,   14,    1,   11,
              14,    8,    8,   18,   34,   18,   34,   36,   46,   26,
              23,   46,   26,   23,    1,   64,   36,   36,    1,   30,
              36,   42,   42,   72,   78,   40,   14,   34,   40,   18,
               4,  118,   52,   36,    1,   30,   36,   42,   12,   36,
              22,   12,   12,   36,
        },

        {
            /* Context Tables for init_idc = 2, qp = 17 */

              14,  124,   14,    5,   43,    1,   48,    5,   15,    1,
               1,   74,    1,    5,    1,    1,   26,   30,    1,   26,
              37,   27,   17,    4,    4,   14,   14,    4,   32,   20,
              27,  106,   36,   20,   14,   49,   78,   10,   36,    1,
               5,    5,   27,   33,   11,   33,   37,   21,   27,   49,
              49,   27,   27,   43,   49,   49,   27,    1,    4,    5,
              27,   33,   11,   33,   37,   21,   27,   49,   49,   27,
              27,   43,   49,   49,   27,    1,    4,    5,   36,   21,
              14,    1,   11,    1,    5,   14,    5,    4,    4,   17,
              11,   52,   26,   21,   42,   14,    1,   52,   26,   21,
              42,   14,    1,   52,   26,   21,   42,   14,    1,   11,
              14,   10,   10,   20,   36,   20,   36,   36,   46,   26,
              21,   46,   26,   21,    1,   64,   36,   36,    1,   30,
              36,   42,   42,   74,   78,   42,   14,   36,   42,   20,
               4,  116,   52,   36,    1,   30,   36,   42,   14,   36,
              26,   14,   14,   36,
        },

        {
            /* Context Tables for init_idc = 2, qp = 18 */

              14,  124,   16,    5,   41,    1,   46,    7,   17,    1,
               1,   74,    1,    5,    1,    1,   24,   30,    1,   26,
              35,   23,   13,    8,    8,   14,   14,    4,   30,   20,
              23,  102,   36,   22,   14,   47,   78,   12,   36,    1,
               5,    5,   25,   31,    9,   31,   35,   19,   25,   47,
              47,   23,   25,   41,   47,   47,   23,    0,    6,    3,
              25,   31,    9,   31,   35,   19,   25,   47,   47,   23,
              25,   41,   47,   47,   23,    0,    6,    3,   38,   21,
              18,    1,   11,    1,    5,   14,    5,    6,    6,   13,
               9,   52,   24,   21,   42,   14,    1,   52,   24,   21,
              42,   14,    1,   52,   24,   21,   42,   14,    1,   11,
              14,   10,   10,   22,   38,   22,   38,   36,   46,   24,
              21,   46,   24,   21,    1,   62,   36,   36,    1,   30,
              36,   40,   40,   74,   78,   42,   14,   38,   42,   22,
               4,  114,   52,   36,    1,   30,   36,   40,   16,   36,
              28,   16,   16,   36,
        },

        {
            /* Context Tables for init_idc = 2, qp = 19 */

              14,  124,   18,    5,   41,    1,   44,    7,   19,    1,
               1,   74,    1,    5,    1,    1,   24,   30,    1,   26,
              33,   21,    9,   14,   14,   14,   14,    4,   28,   20,
              21,  100,   36,   22,   14,   45,   78,   14,   36,    1,
               5,    5,   25,   29,    9,   29,   33,   17,   25,   45,
              45,   21,   25,   41,   45,   45,   21,    2,    6,    1,
              25,   29,    9,   29,   33,   17,   25,   45,   45,   21,
              25,   41,   45,   45,   21,    2,    6,    1,   38,   21,
              22,    1,   11,    1,    5,   14,    5,    6,    6,    9,
               9,   52,   24,   21,   42,   14,    1,   52,   24,   21,
              42,   14,    1,   52,   24,   21,   42,   14,    1,   11,
              14,   10,   10,   22,   38,   22,   38,   36,   46,   24,
              21,   46,   24,   21,    1,   60,   36,   36,    1,   30,
              36,   40,   40,   74,   78,   42,   14,   38,   42,   22,
               4,  112,   52,   36,    1,   30,   36,   40,   18,   36,
              30,   18,   18,   36,
        },

        {
            /* Context Tables for init_idc = 2, qp = 20 */

              14,  124,   20,    3,   39,    1,   42,    9,   21,    1,
               1,   76,    1,    3,    1,    1,   22,   30,    1,   28,
              31,   17,    5,   18,   18,   14,   14,    2,   26,   18,
              17,   96,   34,   24,   14,   43,   78,   16,   34,    1,
               3,    3,   23,   27,    7,   27,   31,   15,   23,   43,
              43,   17,   23,   39,   43,   43,   17,    4,    8,    0,
              23,   27,    7,   27,   31,   15,   23,   43,   43,   17,
              23,   39,   43,   43,   17,    4,    8,    0,   40,   19,
              26,    1,   13,    1,    3,   14,    3,    8,    8,    5,
               7,   50,   22,   19,   44,   14,    1,   50,   22,   19,
              44,   14,    1,   50,   22,   19,   44,   14,    1,   13,
              14,   12,   12,   24,   40,   24,   40,   34,   46,   22,
              19,   46,   22,   19,    1,   58,   34,   34,    1,   30,
              34,   38,   38,   76,   78,   44,   14,   40,   44,   24,
               2,  108,   50,   34,    1,   30,   34,   38,   20,   34,
              32,   20,   20,   34,
        },

        {
            /* Context Tables for init_idc = 2, qp = 21 */

              14,  124,   22,    3,   37,    1,   40,   11,   23,    1,
               1,   76,    1,    3,    1,    1,   20,   30,    1,   28,
              27,   15,    1,   24,   24,   14,   14,    2,   24,   18,
              15,   94,   34,   26,   14,   41,   78,   20,   34,    1,
               3,    3,   21,   25,    5,   25,   27,   11,   21,   41,
              41,   15,   21,   37,   41,   41,   15,    6,   10,    4,
              21,   25,    5,   25,   27,   11,   21,   41,   41,   15,
              21,   37,   41,   41,   15,    6,   10,    4,   42,   19,
              30,    1,   13,    1,    3,   14,    3,   10,   10,    1,
               5,   50,   20,   19,   44,   14,    1,   50,   20,   19,
              44,   14,    1,   50,   20,   19,   44,   14,    1,   13,
              14,   12,   12,   26,   42,   26,   42,   34,   46,   20,
              19,   46,   20,   19,    1,   56,   34,   34,    1,   30,
              34,   36,   36,   76,   78,   44,   14,   42,   44,   26,
               2,  106,   50,   34,    1,   30,   34,   36,   22,   34,
              36,   22,   22,   34,
        },

        {
            /* Context Tables for init_idc = 2, qp = 22 */

              14,  124,   24,    3,   37,    1,   38,   11,   25,    1,
               1,   76,    1,    3,    1,    1,   20,   30,    1,   28,
              25,   11,    2,   28,   28,   14,   14,    2,   22,   18,
              11,   90,   34,   26,   14,   39,   78,   22,   34,    1,
               3,    3,   21,   23,    5,   23,   25,    9,   21,   39,
              39,   11,   21,   37,   39,   39,   11,    8,   10,    6,
              21,   23,    5,   23,   25,    9,   21,   39,   39,   11,
              21,   37,   39,   39,   11,    8,   10,    6,   42,   19,
              34,    1,   13,    1,    3,   14,    3,   10,   10,    2,
               5,   50,   20,   19,   44,   14,    1,   50,   20,   19,
              44,   14,    1,   50,   20,   19,   44,   14,    1,   13,
              14,   12,   12,   26,   42,   26,   42,   34,   46,   20,
              19,   46,   20,   19,    1,   54,   34,   34,    1,   30,
              34,   36,   36,   76,   78,   44,   14,   42,   44,   26,
               2,  104,   50,   34,    1,   30,   34,   36,   24,   34,
              38,   24,   24,   34,
        },

        {
            /* Context Tables for init_idc = 2, qp = 23 */

              14,  124,   26,    1,   35,    1,   36,   13,   27,    1,
               1,   78,    1,    1,    1,    1,   18,   30,    1,   30,
              23,    9,    6,   34,   34,   14,   14,    0,   20,   16,
               9,   88,   32,   28,   14,   37,   78,   24,   32,    1,
               1,    1,   19,   21,    3,   21,   23,    7,   19,   37,
              37,    9,   19,   35,   37,   37,    9,   10,   12,    8,
              19,   21,    3,   21,   23,    7,   19,   37,   37,    9,
              19,   35,   37,   37,    9,   10,   12,    8,   44,   17,
              38,    1,   15,    1,    1,   14,    1,   12,   12,    6,
               3,   48,   18,   17,   46,   14,    1,   48,   18,   17,
              46,   14,    1,   48,   18,   17,   46,   14,    1,   15,
              14,   14,   14,   28,   44,   28,   44,   32,   46,   18,
              17,   46,   18,   17,    1,   52,   32,   32,    1,   30,
              32,   34,   34,   78,   78,   46,   14,   44,   46,   28,
               0,  102,   48,   32,    1,   30,   32,   34,   26,   32,
              40,   26,   26,   32,
        },

        {
            /* Context Tables for init_idc = 2, qp = 24 */

              14,  124,   28,    1,   35,    1,   34,   15,   29,    1,
               1,   78,    1,    1,    1,    1,   16,   30,    1,   30,
              21,    5,    8,   38,   38,   14,   14,    0,   18,   16,
               5,   84,   32,   28,   14,   35,   78,   26,   32,    1,
               1,    1,   19,   19,    3,   19,   21,    5,   19,   35,
              35,    5,   19,   35,   35,   35,    5,   12,   12,   10,
              19,   19,    3,   19,   21,    5,   19,   35,   35,    5,
              19,   35,   35,   35,    5,   12,   12,   10,   44,   17,
              40,    1,   15,    1,    1,   14,    1,   12,   12,    8,
               3,   48,   16,   17,   46,   14,    1,   48,   16,   17,
              46,   14,    1,   48,   16,   17,   46,   14,    1,   15,
              14,   14,   14,   28,   44,   28,   44,   32,   46,   16,
              17,   46,   16,   17,    1,   50,   32,   32,    1,   30,
              32,   32,   32,   78,   78,   46,   14,   44,   46,   28,
               0,   98,   48,   32,    1,   30,   32,   32,   28,   32,
              42,   28,   28,   32,
        },

        {
            /* Context Tables for init_idc = 2, qp = 25 */

              14,  124,   30,    1,   33,    1,   32,   15,   31,    1,
               1,   78,    1,    1,    1,    1,   16,   30,    1,   30,
              17,    1,   12,   44,   44,   14,   14,    0,   16,   16,
               1,   80,   32,   30,   14,   33,   78,   30,   32,    1,
               1,    1,   17,   17,    1,   17,   17,    1,   17,   33,
              33,    1,   17,   33,   33,   33,    1,   14,   14,   14,
              17,   17,    1,   17,   17,    1,   17,   33,   33,    1,
              17,   33,   33,   33,    1,   14,   14,   14,   46,   17,
              44,    1,   15,    1,    1,   14,    1,   14,   14,   12,
               1,   48,   16,   17,   46,   14,    1,   48,   16,   17,
              46,   14,    1,   48,   16,   17,   46,   14,    1,   15,
              14,   14,   14,   30,   46,   30,   46,   32,   46,   16,
              17,   46,   16,   17,    1,   48,   32,   32,    1,   30,
              32,   32,   32,   78,   78,   46,   14,   46,   46,   30,
               0,   96,   48,   32,    1,   30,   32,   32,   30,   32,
              46,   30,   30,   32,
        },

        {
            /* Context Tables for init_idc = 2, qp = 26 */

              14,  124,   32,    0,   31,    1,   30,   17,   33,    1,
               1,   80,    1,    0,    1,    1,   14,   30,    1,   32,
              15,    0,   16,   48,   48,   14,   14,    1,   14,   14,
               0,   78,   30,   32,   14,   31,   78,   32,   30,    1,
               0,    0,   15,   15,    0,   15,   15,    0,   15,   31,
              31,    0,   15,   31,   31,   31,    0,   16,   16,   16,
              15,   15,    0,   15,   15,    0,   15,   31,   31,    0,
              15,   31,   31,   31,    0,   16,   16,   16,   48,   15,
              48,    1,   17,    1,    0,   14,    0,   16,   16,   16,
               0,   46,   14,   15,   48,   14,    1,   46,   14,   15,
              48,   14,    1,   46,   14,   15,   48,   14,    1,   17,
              14,   16,   16,   32,   48,   32,   48,   30,   46,   14,
              15,   46,   14,   15,    1,   46,   30,   30,    1,   30,
              30,   30,   30,   80,   78,   48,   14,   48,   48,   32,
               1,   94,   46,   30,    1,   30,   30,   30,   32,   30,
              48,   32,   32,   30,
        },

        {
            /* Context Tables for init_idc = 2, qp = 27 */

              14,  124,   34,    0,   31,    1,   28,   17,   35,    1,
               1,   80,    1,    0,    1,    1,   14,   30,    1,   32,
              13,    4,   20,   54,   54,   14,   14,    1,   12,   14,
               4,   74,   30,   32,   14,   29,   78,   34,   30,    1,
               0,    0,   15,   13,    0,   13,   13,    2,   15,   29,
              29,    4,   15,   31,   29,   29,    4,   18,   16,   18,
              15,   13,    0,   13,   13,    2,   15,   29,   29,    4,
              15,   31,   29,   29,    4,   18,   16,   18,   48,   15,
              52,    1,   17,    1,    0,   14,    0,   16,   16,   20,
               0,   46,   14,   15,   48,   14,    1,   46,   14,   15,
              48,   14,    1,   46,   14,   15,   48,   14,    1,   17,
              14,   16,   16,   32,   48,   32,   48,   30,   46,   14,
              15,   46,   14,   15,    1,   44,   30,   30,    1,   30,
              30,   30,   30,   80,   78,   48,   14,   48,   48,   32,
               1,   92,   46,   30,    1,   30,   30,   30,   34,   30,
              50,   34,   34,   30,
        },

        {
            /* Context Tables for init_idc = 2, qp = 28 */

              14,  124,   36,    0,   29,    1,   26,   19,   37,    1,
               1,   80,    1,    0,    1,    1,   12,   30,    1,   32,
              11,    6,   24,   58,   58,   14,   14,    1,   10,   14,
               6,   72,   30,   34,   14,   27,   78,   36,   30,    1,
               0,    0,   13,   11,    2,   11,   11,    4,   13,   27,
              27,    6,   13,   29,   27,   27,    6,   20,   18,   20,
              13,   11,    2,   11,   11,    4,   13,   27,   27,    6,
              13,   29,   27,   27,    6,   20,   18,   20,   50,   15,
              56,    1,   17,    1,    0,   14,    0,   18,   18,   24,
               2,   46,   12,   15,   48,   14,    1,   46,   12,   15,
              48,   14,    1,   46,   12,   15,   48,   14,    1,   17,
              14,   16,   16,   34,   50,   34,   50,   30,   46,   12,
              15,   46,   12,   15,    1,   42,   30,   30,    1,   30,
              30,   28,   28,   80,   78,   48,   14,   50,   48,   34,
               1,   88,   46,   30,    1,   30,   30,   28,   36,   30,
              52,   36,   36,   30,
        },

        {
            /* Context Tables for init_idc = 2, qp = 29 */

              14,  124,   38,    2,   27,    1,   24,   21,   39,    1,
               1,   82,    1,    2,    1,    1,   10,   30,    1,   34,
               7,   10,   28,   64,   64,   14,   14,    3,    8,   12,
              10,   68,   28,   36,   14,   25,   78,   40,   28,    1,
               2,    2,   11,    9,    4,    9,    7,    8,   11,   25,
              25,   10,   11,   27,   25,   25,   10,   22,   20,   24,
              11,    9,    4,    9,    7,    8,   11,   25,   25,   10,
              11,   27,   25,   25,   10,   22,   20,   24,   52,   13,
              60,    1,   19,    1,    2,   14,    2,   20,   20,   28,
               4,   44,   10,   13,   50,   14,    1,   44,   10,   13,
              50,   14,    1,   44,   10,   13,   50,   14,    1,   19,
              14,   18,   18,   36,   52,   36,   52,   28,   46,   10,
              13,   46,   10,   13,    1,   40,   28,   28,    1,   30,
              28,   26,   26,   82,   78,   50,   14,   52,   50,   36,
               3,   86,   44,   28,    1,   30,   28,   26,   38,   28,
              56,   38,   38,   28,
        },

        {
            /* Context Tables for init_idc = 2, qp = 30 */

              14,  124,   40,    2,   27,    1,   22,   21,   41,    1,
               1,   82,    1,    2,    1,    1,   10,   30,    1,   34,
               5,   12,   32,   68,   68,   14,   14,    3,    6,   12,
              12,   66,   28,   36,   14,   23,   78,   42,   28,    1,
               2,    2,   11,    7,    4,    7,    5,   10,   11,   23,
              23,   12,   11,   27,   23,   23,   12,   24,   20,   26,
              11,    7,    4,    7,    5,   10,   11,   23,   23,   12,
              11,   27,   23,   23,   12,   24,   20,   26,   52,   13,
              64,    1,   19,    1,    2,   14,    2,   20,   20,   32,
               4,   44,   10,   13,   50,   14,    1,   44,   10,   13,
              50,   14,    1,   44,   10,   13,   50,   14,    1,   19,
              14,   18,   18,   36,   52,   36,   52,   28,   46,   10,
              13,   46,   10,   13,    1,   38,   28,   28,    1,   30,
              28,   26,   26,   82,   78,   50,   14,   52,   50,   36,
               3,   84,   44,   28,    1,   30,   28,   26,   40,   28,
              58,   40,   40,   28,
        },

        {
            /* Context Tables for init_idc = 2, qp = 31 */

              14,  124,   42,    2,   25,    1,   20,   23,   43,    1,
               1,   82,    1,    2,    1,    1,    8,   30,    1,   34,
               3,   16,   36,   74,   74,   14,   14,    3,    4,   12,
              16,   62,   28,   38,   14,   21,   78,   44,   28,    1,
               2,    2,    9,    5,    6,    5,    3,   12,    9,   21,
              21,   16,    9,   25,   21,   21,   16,   26,   22,   28,
               9,    5,    6,    5,    3,   12,    9,   21,   21,   16,
               9,   25,   21,   21,   16,   26,   22,   28,   54,   13,
              68,    1,   19,    1,    2,   14,    2,   22,   22,   36,
               6,   44,    8,   13,   50,   14,    1,   44,    8,   13,
              50,   14,    1,   44,    8,   13,   50,   14,    1,   19,
              14,   18,   18,   38,   54,   38,   54,   28,   46,    8,
              13,   46,    8,   13,    1,   36,   28,   28,    1,   30,
              28,   24,   24,   82,   78,   50,   14,   54,   50,   38,
               3,   82,   44,   28,    1,   30,   28,   24,   42,   28,
              60,   42,   42,   28,
        },

        {
            /* Context Tables for init_idc = 2, qp = 32 */

              14,  124,   42,    2,   25,    1,   18,   25,   45,    1,
               1,   82,    1,    2,    1,    1,    6,   30,    1,   34,
               1,   18,   38,   78,   78,   14,   14,    5,    2,   10,
              18,   58,   26,   38,   14,   21,   78,   46,   26,    1,
               2,    2,    9,    5,    6,    5,    1,   14,    9,   21,
              21,   18,    9,   25,   21,   21,   18,   26,   22,   30,
               9,    5,    6,    5,    1,   14,    9,   21,   21,   18,
               9,   25,   21,   21,   18,   26,   22,   30,   54,   13,
              70,    1,   21,    1,    2,   14,    2,   22,   22,   38,
               6,   42,    6,   13,   50,   14,    1,   42,    6,   13,
              50,   14,    1,   42,    6,   13,   50,   14,    1,   21,
              14,   18,   18,   38,   54,   38,   54,   26,   46,    6,
              13,   46,    6,   13,    1,   34,   26,   26,    1,   30,
              26,   22,   22,   82,   78,   50,   14,   54,   50,   38,
               5,   78,   42,   26,    1,   30,   26,   22,   42,   26,
              62,   42,   42,   26,
        },

        {
            /* Context Tables for init_idc = 2, qp = 33 */

              14,  124,   44,    4,   23,    1,   18,   25,   45,    1,
               1,   84,    1,    4,    1,    1,    6,   30,    1,   36,
               2,   22,   42,   84,   84,   14,   14,    5,    2,   10,
              22,   56,   26,   40,   14,   19,   78,   50,   26,    1,
               4,    4,    7,    3,    8,    3,    2,   18,    7,   19,
              19,   22,    7,   23,   19,   19,   22,   28,   24,   34,
               7,    3,    8,    3,    2,   18,    7,   19,   19,   22,
               7,   23,   19,   19,   22,   28,   24,   34,   56,   11,
              74,    1,   21,    1,    4,   14,    4,   24,   24,   42,
               8,   42,    6,   11,   52,   14,    1,   42,    6,   11,
              52,   14,    1,   42,    6,   11,   52,   14,    1,   21,
              14,   20,   20,   40,   56,   40,   56,   26,   46,    6,
              11,   46,    6,   11,    1,   34,   26,   26,    1,   30,
              26,   22,   22,   84,   78,   52,   14,   56,   52,   40,
               5,   76,   42,   26,    1,   30,   26,   22,   44,   26,
              66,   44,   44,   26,
        },

        {
            /* Context Tables for init_idc = 2, qp = 34 */

              14,  124,   46,    4,   21,    1,   16,   27,   47,    1,
               1,   84,    1,    4,    1,    1,    4,   30,    1,   36,
               4,   26,   46,   88,   88,   14,   14,    5,    0,   10,
              26,   52,   26,   42,   14,   17,   78,   52,   26,    1,
               4,    4,    5,    1,   10,    1,    4,   20,    5,   17,
              17,   26,    5,   21,   17,   17,   26,   30,   26,   36,
               5,    1,   10,    1,    4,   20,    5,   17,   17,   26,
               5,   21,   17,   17,   26,   30,   26,   36,   58,   11,
              78,    1,   21,    1,    4,   14,    4,   26,   26,   46,
              10,   42,    4,   11,   52,   14,    1,   42,    4,   11,
              52,   14,    1,   42,    4,   11,   52,   14,    1,   21,
              14,   20,   20,   42,   58,   42,   58,   26,   46,    4,
              11,   46,    4,   11,    1,   32,   26,   26,    1,   30,
              26,   20,   20,   84,   78,   52,   14,   58,   52,   42,
               5,   74,   42,   26,    1,   30,   26,   20,   46,   26,
              68,   46,   46,   26,
        },

        {
            /* Context Tables for init_idc = 2, qp = 35 */

              14,  124,   48,    4,   21,    1,   14,   27,   49,    1,
               1,   84,    1,    4,    1,    1,    4,   30,    1,   36,
               6,   28,   50,   94,   94,   14,   14,    5,    1,   10,
              28,   50,   26,   42,   14,   15,   78,   54,   26,    1,
               4,    4,    5,    0,   10,    0,    6,   22,    5,   15,
              15,   28,    5,   21,   15,   15,   28,   32,   26,   38,
               5,    0,   10,    0,    6,   22,    5,   15,   15,   28,
               5,   21,   15,   15,   28,   32,   26,   38,   58,   11,
              82,    1,   21,    1,    4,   14,    4,   26,   26,   50,
              10,   42,    4,   11,   52,   14,    1,   42,    4,   11,
              52,   14,    1,   42,    4,   11,   52,   14,    1,   21,
              14,   20,   20,   42,   58,   42,   58,   26,   46,    4,
              11,   46,    4,   11,    1,   30,   26,   26,    1,   30,
              26,   20,   20,   84,   78,   52,   14,   58,   52,   42,
               5,   72,   42,   26,    1,   30,   26,   20,   48,   26,
              70,   48,   48,   26,
        },

        {
            /* Context Tables for init_idc = 2, qp = 36 */

              14,  124,   50,    6,   19,    1,   12,   29,   51,    1,
               1,   86,    1,    6,    1,    1,    2,   30,    1,   38,
               8,   32,   54,   98,   98,   14,   14,    7,    3,    8,
              32,   46,   24,   44,   14,   13,   78,   56,   24,    1,
               6,    6,    3,    2,   12,    2,    8,   24,    3,   13,
              13,   32,    3,   19,   13,   13,   32,   34,   28,   40,
               3,    2,   12,    2,    8,   24,    3,   13,   13,   32,
               3,   19,   13,   13,   32,   34,   28,   40,   60,    9,
              86,    1,   23,    1,    6,   14,    6,   28,   28,   54,
              12,   40,    2,    9,   54,   14,    1,   40,    2,    9,
              54,   14,    1,   40,    2,    9,   54,   14,    1,   23,
              14,   22,   22,   44,   60,   44,   60,   24,   46,    2,
               9,   46,    2,    9,    1,   28,   24,   24,    1,   30,
              24,   18,   18,   86,   78,   54,   14,   60,   54,   44,
               7,   68,   40,   24,    1,   30,   24,   18,   50,   24,
              72,   50,   50,   24,
        },

        {
            /* Context Tables for init_idc = 2, qp = 37 */

              14,  124,   52,    6,   17,    1,   10,   31,   53,    1,
               1,   86,    1,    6,    1,    1,    0,   30,    1,   38,
              12,   34,   58,  104,  104,   14,   14,    7,    5,    8,
              34,   44,   24,   46,   14,   11,   78,   60,   24,    1,
               6,    6,    1,    4,   14,    4,   12,   28,    1,   11,
              11,   34,    1,   17,   11,   11,   34,   36,   30,   44,
               1,    4,   14,    4,   12,   28,    1,   11,   11,   34,
               1,   17,   11,   11,   34,   36,   30,   44,   62,    9,
              90,    1,   23,    1,    6,   14,    6,   30,   30,   58,
              14,   40,    0,    9,   54,   14,    1,   40,    0,    9,
              54,   14,    1,   40,    0,    9,   54,   14,    1,   23,
              14,   22,   22,   46,   62,   46,   62,   24,   46,    0,
               9,   46,    0,    9,    1,   26,   24,   24,    1,   30,
              24,   16,   16,   86,   78,   54,   14,   62,   54,   46,
               7,   66,   40,   24,    1,   30,   24,   16,   52,   24,
              76,   52,   52,   24,
        },

        {
            /* Context Tables for init_idc = 2, qp = 38 */

              14,  124,   54,    6,   17,    1,    8,   31,   55,    1,
               1,   86,    1,    6,    1,    1,    0,   30,    1,   38,
              14,   38,   62,  108,  108,   14,   14,    7,    7,    8,
              38,   40,   24,   46,   14,    9,   78,   62,   24,    1,
               6,    6,    1,    6,   14,    6,   14,   30,    1,    9,
               9,   38,    1,   17,    9,    9,   38,   38,   30,   46,
               1,    6,   14,    6,   14,   30,    1,    9,    9,   38,
               1,   17,    9,    9,   38,   38,   30,   46,   62,    9,
              94,    1,   23,    1,    6,   14,    6,   30,   30,   62,
              14,   40,    0,    9,   54,   14,    1,   40,    0,    9,
              54,   14,    1,   40,    0,    9,   54,   14,    1,   23,
              14,   22,   22,   46,   62,   46,   62,   24,   46,    0,
               9,   46,    0,    9,    1,   24,   24,   24,    1,   30,
              24,   16,   16,   86,   78,   54,   14,   62,   54,   46,
               7,   64,   40,   24,    1,   30,   24,   16,   54,   24,
              78,   54,   54,   24,
        },

        {
            /* Context Tables for init_idc = 2, qp = 39 */

              14,  124,   56,    8,   15,    1,    6,   33,   57,    1,
               1,   88,    1,    8,    1,    1,    1,   30,    1,   40,
              16,   40,   66,  114,  114,   14,   14,    9,    9,    6,
              40,   38,   22,   48,   14,    7,   78,   64,   22,    1,
               8,    8,    0,    8,   16,    8,   16,   32,    0,    7,
               7,   40,    0,   15,    7,    7,   40,   40,   32,   48,
               0,    8,   16,    8,   16,   32,    0,    7,    7,   40,
               0,   15,    7,    7,   40,   40,   32,   48,   64,    7,
              98,    1,   25,    1,    8,   14,    8,   32,   32,   66,
              16,   38,    1,    7,   56,   14,    1,   38,    1,    7,
              56,   14,    1,   38,    1,    7,   56,   14,    1,   25,
              14,   24,   24,   48,   64,   48,   64,   22,   46,    1,
               7,   46,    1,    7,    1,   22,   22,   22,    1,   30,
              22,   14,   14,   88,   78,   56,   14,   64,   56,   48,
               9,   62,   38,   22,    1,   30,   22,   14,   56,   22,
              80,   56,   56,   22,
        },

        {
            /* Context Tables for init_idc = 2, qp = 40 */

              14,  124,   58,    8,   15,    1,    4,   35,   59,    1,
               1,   88,    1,    8,    1,    1,    3,   30,    1,   40,
              18,   44,   68,  118,  118,   14,   14,    9,   11,    6,
              44,   34,   22,   48,   14,    5,   78,   66,   22,    1,
               8,    8,    0,   10,   16,   10,   18,   34,    0,    5,
               5,   44,    0,   15,    5,    5,   44,   42,   32,   50,
               0,   10,   16,   10,   18,   34,    0,    5,    5,   44,
               0,   15,    5,    5,   44,   42,   32,   50,   64,    7,
             100,    1,   25,    1,    8,   14,    8,   32,   32,   68,
              16,   38,    3,    7,   56,   14,    1,   38,    3,    7,
              56,   14,    1,   38,    3,    7,   56,   14,    1,   25,
              14,   24,   24,   48,   64,   48,   64,   22,   46,    3,
               7,   46,    3,    7,    1,   20,   22,   22,    1,   30,
              22,   12,   12,   88,   78,   56,   14,   64,   56,   48,
               9,   58,   38,   22,    1,   30,   22,   12,   58,   22,
              82,   58,   58,   22,
        },

        {
            /* Context Tables for init_idc = 2, qp = 41 */

              14,  124,   60,    8,   13,    1,    2,   35,   61,    1,
               1,   88,    1,    8,    1,    1,    3,   30,    1,   40,
              22,   48,   72,  124,  124,   14,   14,    9,   13,    6,
              48,   30,   22,   50,   14,    3,   78,   70,   22,    1,
               8,    8,    2,   12,   18,   12,   22,   38,    2,    3,
               3,   48,    2,   13,    3,    3,   48,   44,   34,   54,
               2,   12,   18,   12,   22,   38,    2,    3,    3,   48,
               2,   13,    3,    3,   48,   44,   34,   54,   66,    7,
             104,    1,   25,    1,    8,   14,    8,   34,   34,   72,
              18,   38,    3,    7,   56,   14,    1,   38,    3,    7,
              56,   14,    1,   38,    3,    7,   56,   14,    1,   25,
              14,   24,   24,   50,   66,   50,   66,   22,   46,    3,
               7,   46,    3,    7,    1,   18,   22,   22,    1,   30,
              22,   12,   12,   88,   78,   56,   14,   66,   56,   50,
               9,   56,   38,   22,    1,   30,   22,   12,   60,   22,
              86,   60,   60,   22,
        },

        {
            /* Context Tables for init_idc = 2, qp = 42 */

              14,  124,   62,   10,   11,    1,    0,   37,   63,    1,
               1,   90,    1,   10,    1,    1,    5,   30,    1,   42,
              24,   50,   76,  124,  124,   14,   14,   11,   15,    4,
              50,   28,   20,   52,   14,    1,   78,   72,   20,    1,
              10,   10,    4,   14,   20,   14,   24,   40,    4,    1,
               1,   50,    4,   11,    1,    1,   50,   46,   36,   56,
               4,   14,   20,   14,   24,   40,    4,    1,    1,   50,
               4,   11,    1,    1,   50,   46,   36,   56,   68,    5,
             108,    1,   27,    1,   10,   14,   10,   36,   36,   76,
              20,   36,    5,    5,   58,   14,    1,   36,    5,    5,
              58,   14,    1,   36,    5,    5,   58,   14,    1,   27,
              14,   26,   26,   52,   68,   52,   68,   20,   46,    5,
               5,   46,    5,    5,    1,   16,   20,   20,    1,   30,
              20,   10,   10,   90,   78,   58,   14,   68,   58,   52,
              11,   54,   36,   20,    1,   30,   20,   10,   62,   20,
              88,   62,   62,   20,
        },

        {
            /* Context Tables for init_idc = 2, qp = 43 */

              14,  124,   64,   10,   11,    1,    1,   37,   65,    1,
               1,   90,    1,   10,    1,    1,    5,   30,    1,   42,
              26,   54,   80,  124,  124,   14,   14,   11,   17,    4,
              54,   24,   20,   52,   14,    0,   78,   74,   20,    1,
              10,   10,    4,   16,   20,   16,   26,   42,    4,    0,
               0,   54,    4,   11,    0,    0,   54,   48,   36,   58,
               4,   16,   20,   16,   26,   42,    4,    0,    0,   54,
               4,   11,    0,    0,   54,   48,   36,   58,   68,    5,
             112,    1,   27,    1,   10,   14,   10,   36,   36,   80,
              20,   36,    5,    5,   58,   14,    1,   36,    5,    5,
              58,   14,    1,   36,    5,    5,   58,   14,    1,   27,
              14,   26,   26,   52,   68,   52,   68,   20,   46,    5,
               5,   46,    5,    5,    1,   14,   20,   20,    1,   30,
              20,   10,   10,   90,   78,   58,   14,   68,   58,   52,
              11,   52,   36,   20,    1,   30,   20,   10,   64,   20,
              90,   64,   64,   20,
        },

        {
            /* Context Tables for init_idc = 2, qp = 44 */

              14,  124,   66,   10,    9,    1,    3,   39,   67,    1,
               1,   90,    1,   10,    1,    1,    7,   30,    1,   42,
              28,   56,   84,  124,  124,   14,   14,   11,   19,    4,
              56,   22,   20,   54,   14,    2,   78,   76,   20,    1,
              10,   10,    6,   18,   22,   18,   28,   44,    6,    2,
               2,   56,    6,    9,    2,    2,   56,   50,   38,   60,
               6,   18,   22,   18,   28,   44,    6,    2,    2,   56,
               6,    9,    2,    2,   56,   50,   38,   60,   70,    5,
             116,    1,   27,    1,   10,   14,   10,   38,   38,   84,
              22,   36,    7,    5,   58,   14,    1,   36,    7,    5,
              58,   14,    1,   36,    7,    5,   58,   14,    1,   27,
              14,   26,   26,   54,   70,   54,   70,   20,   46,    7,
               5,   46,    7,    5,    1,   12,   20,   20,    1,   30,
              20,    8,    8,   90,   78,   58,   14,   70,   58,   54,
              11,   48,   36,   20,    1,   30,   20,    8,   66,   20,
              92,   66,   66,   20,
        },

        {
            /* Context Tables for init_idc = 2, qp = 45 */

              14,  124,   68,   12,    7,    1,    5,   41,   69,    1,
               1,   92,    1,   12,    1,    1,    9,   30,    1,   44,
              32,   60,   88,  124,  124,   14,   14,   13,   21,    2,
              60,   18,   18,   56,   14,    4,   78,   80,   18,    1,
              12,   12,    8,   20,   24,   20,   32,   48,    8,    4,
               4,   60,    8,    7,    4,    4,   60,   52,   40,   64,
               8,   20,   24,   20,   32,   48,    8,    4,    4,   60,
               8,    7,    4,    4,   60,   52,   40,   64,   72,    3,
             120,    1,   29,    1,   12,   14,   12,   40,   40,   88,
              24,   34,    9,    3,   60,   14,    1,   34,    9,    3,
              60,   14,    1,   34,    9,    3,   60,   14,    1,   29,
              14,   28,   28,   56,   72,   56,   72,   18,   46,    9,
               3,   46,    9,    3,    1,   10,   18,   18,    1,   30,
              18,    6,    6,   92,   78,   60,   14,   72,   60,   56,
              13,   46,   34,   18,    1,   30,   18,    6,   68,   18,
              96,   68,   68,   18,
        },

        {
            /* Context Tables for init_idc = 2, qp = 46 */

              14,  124,   70,   12,    7,    1,    7,   41,   71,    1,
               1,   92,    1,   12,    1,    1,    9,   30,    1,   44,
              34,   62,   92,  124,  124,   14,   14,   13,   23,    2,
              62,   16,   18,   56,   14,    6,   78,   82,   18,    1,
              12,   12,    8,   22,   24,   22,   34,   50,    8,    6,
               6,   62,    8,    7,    6,    6,   62,   54,   40,   66,
               8,   22,   24,   22,   34,   50,    8,    6,    6,   62,
               8,    7,    6,    6,   62,   54,   40,   66,   72,    3,
             124,    1,   29,    1,   12,   14,   12,   40,   40,   92,
              24,   34,    9,    3,   60,   14,    1,   34,    9,    3,
              60,   14,    1,   34,    9,    3,   60,   14,    1,   29,
              14,   28,   28,   56,   72,   56,   72,   18,   46,    9,
               3,   46,    9,    3,    1,    8,   18,   18,    1,   30,
              18,    6,    6,   92,   78,   60,   14,   72,   60,   56,
              13,   44,   34,   18,    1,   30,   18,    6,   70,   18,
              98,   70,   70,   18,
        },

        {
            /* Context Tables for init_idc = 2, qp = 47 */

              14,  124,   72,   12,    5,    1,    9,   43,   73,    1,
               1,   92,    1,   12,    1,    1,   11,   30,    1,   44,
              36,   66,   96,  124,  124,   14,   14,   13,   25,    2,
              66,   12,   18,   58,   14,    8,   78,   84,   18,    1,
              12,   12,   10,   24,   26,   24,   36,   52,   10,    8,
               8,   66,   10,    5,    8,    8,   66,   56,   42,   68,
              10,   24,   26,   24,   36,   52,   10,    8,    8,   66,
              10,    5,    8,    8,   66,   56,   42,   68,   74,    3,
             124,    1,   29,    1,   12,   14,   12,   42,   42,   96,
              26,   34,   11,    3,   60,   14,    1,   34,   11,    3,
              60,   14,    1,   34,   11,    3,   60,   14,    1,   29,
              14,   28,   28,   58,   74,   58,   74,   18,   46,   11,
               3,   46,   11,    3,    1,    6,   18,   18,    1,   30,
              18,    4,    4,   92,   78,   60,   14,   74,   60,   58,
              13,   42,   34,   18,    1,   30,   18,    4,   72,   18,
             100,   72,   72,   18,
        },

        {
            /* Context Tables for init_idc = 2, qp = 48 */

              14,  124,   72,   12,    5,    1,   11,   45,   75,    1,
               1,   92,    1,   12,    1,    1,   13,   30,    1,   44,
              38,   68,   98,  124,  124,   14,   14,   15,   27,    0,
              68,    8,   16,   58,   14,    8,   78,   86,   16,    1,
              12,   12,   10,   24,   26,   24,   38,   54,   10,    8,
               8,   68,   10,    5,    8,    8,   68,   56,   42,   70,
              10,   24,   26,   24,   38,   54,   10,    8,    8,   68,
              10,    5,    8,    8,   68,   56,   42,   70,   74,    3,
             124,    1,   31,    1,   12,   14,   12,   42,   42,   98,
              26,   32,   13,    3,   60,   14,    1,   32,   13,    3,
              60,   14,    1,   32,   13,    3,   60,   14,    1,   31,
              14,   28,   28,   58,   74,   58,   74,   16,   46,   13,
               3,   46,   13,    3,    1,    4,   16,   16,    1,   30,
              16,    2,    2,   92,   78,   60,   14,   74,   60,   58,
              15,   38,   32,   16,    1,   30,   16,    2,   72,   16,
             102,   72,   72,   16,
        },

        {
            /* Context Tables for init_idc = 2, qp = 49 */

              14,  124,   74,   14,    3,    1,   11,   45,   75,    1,
               1,   94,    1,   14,    1,    1,   13,   30,    1,   46,
              42,   72,  102,  124,  124,   14,   14,   15,   27,    0,
              72,    6,   16,   60,   14,   10,   78,   90,   16,    1,
              14,   14,   12,   26,   28,   26,   42,   58,   12,   10,
              10,   72,   12,    3,   10,   10,   72,   58,   44,   74,
              12,   26,   28,   26,   42,   58,   12,   10,   10,   72,
              12,    3,   10,   10,   72,   58,   44,   74,   76,    1,
             124,    1,   31,    1,   14,   14,   14,   44,   44,  102,
              28,   32,   13,    1,   62,   14,    1,   32,   13,    1,
              62,   14,    1,   32,   13,    1,   62,   14,    1,   31,
              14,   30,   30,   60,   76,   60,   76,   16,   46,   13,
               1,   46,   13,    1,    1,    4,   16,   16,    1,   30,
              16,    2,    2,   94,   78,   62,   14,   76,   62,   60,
              15,   36,   32,   16,    1,   30,   16,    2,   74,   16,
             106,   74,   74,   16,
        },

        {
            /* Context Tables for init_idc = 2, qp = 50 */

              14,  124,   76,   14,    1,    1,   13,   47,   77,    1,
               1,   94,    1,   14,    1,    1,   15,   30,    1,   46,
              44,   76,  106,  124,  124,   14,   14,   15,   29,    0,
              76,    2,   16,   62,   14,   12,   78,   92,   16,    1,
              14,   14,   14,   28,   30,   28,   44,   60,   14,   12,
              12,   76,   14,    1,   12,   12,   76,   60,   46,   76,
              14,   28,   30,   28,   44,   60,   14,   12,   12,   76,
              14,    1,   12,   12,   76,   60,   46,   76,   78,    1,
             124,    1,   31,    1,   14,   14,   14,   46,   46,  106,
              30,   32,   15,    1,   62,   14,    1,   32,   15,    1,
              62,   14,    1,   32,   15,    1,   62,   14,    1,   31,
              14,   30,   30,   62,   78,   62,   78,   16,   46,   15,
               1,   46,   15,    1,    1,    2,   16,   16,    1,   30,
              16,    0,    0,   94,   78,   62,   14,   78,   62,   62,
              15,   34,   32,   16,    1,   30,   16,    0,   76,   16,
             108,   76,   76,   16,
        },

        {
            /* Context Tables for init_idc = 2, qp = 51 */

              14,  124,   78,   14,    1,    1,   15,   47,   79,    1,
               1,   94,    1,   14,    1,    1,   15,   30,    1,   46,
              46,   78,  110,  124,  124,   14,   14,   15,   31,    0,
              78,    0,   16,   62,   14,   14,   78,   94,   16,    1,
              14,   14,   14,   30,   30,   30,   46,   62,   14,   14,
              14,   78,   14,    1,   14,   14,   78,   62,   46,   78,
              14,   30,   30,   30,   46,   62,   14,   14,   14,   78,
              14,    1,   14,   14,   78,   62,   46,   78,   78,    1,
             124,    1,   31,    1,   14,   14,   14,   46,   46,  110,
              30,   32,   15,    1,   62,   14,    1,   32,   15,    1,
              62,   14,    1,   32,   15,    1,   62,   14,    1,   31,
              14,   30,   30,   62,   78,   62,   78,   16,   46,   15,
               1,   46,   15,    1,    1,    0,   16,   16,    1,   30,
              16,    0,    0,   94,   78,   62,   14,   78,   62,   62,
              15,   32,   32,   16,    1,   30,   16,    0,   78,   16,
             110,   78,   78,   16,
        },
    },
};
